/*****************************************************************************
 * ADC driver
 *****************************************************************************
 * FileName:        ADC.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar		    4/17/2014	...
 *****************************************************************************/

#include "ADC.h"


/********************************************************************/
#define __ADC_ISR    __ISR(_ADC_VECTOR, ipl4)

void __ADC_ISR _ADCInterrupt(void)
{
  mAD1ClearIntFlag();                       // Clear Interrupt flag
  AD1CON1bits.ASAM = 0;                     // Stop Sampling 
  ADC_Array[ADC_Channel] = ADC1BUF0;     // Get and save current channel value (only 8bit)
  ADC_Channel++;
  if (ADC_Channel > 3)
   {
     ADC_Channel = 0;
   }
  AD1CHS = (ADC_Channel + 2)<<16;
  AD1CON1bits.ASAM = 1;                        // auto start sampling
}

/********************************************************************/
void ADCInit(void)
{
ADC_Channel = 0;             // Set the channel to 0

AD1PCFGCLR = 0x003C;        // AN2, AN3, AN4 and AN5 are enabled as analog inputs
AD1CON1 = 0x0000;            
AD1CON2 = 0x0000;           
AD1CON3 = 0x0000;           
AD1CHS = 0x00000000;

AD1CON1bits.SSRC = 7;         // Auto conversion
AD1CON1bits.ASAM = 1;         // Auto Sampling
AD1CON1bits.SAMP = 0;         // Holding


AD1CON2bits.SMPI = 0;               // Interrupts every 1 samples

AD1CON3bits.SAMC = 0x1f;            // TS = 31TAD
AD1CON3bits.ADCS = 0xff;            // TAD = 512 * TP

AD1CHS = (ADC_Channel + 2)<<16;

mAD1ClearIntFlag();
mAD1SetIntPriority(4);
mAD1SetIntSubPriority(0);
mAD1IntEnable(1);                      // Enable ADC Interrupt

AD1CON1SET = 0x8000;                  // turn ADC ON
}


