/*****************************************************************************
 * SegeNT GUI and Graphics definations
 *****************************************************************************
 * FileName:        GUI.h
 * Dependencies:       
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar         4/17/2014
 *****************************************************************************/

/*****************************************************************************/
#define RGB565CONVERT(red, green, blue)\
(WORD)( (( red   >> 3 ) << 11 ) | \
(( green >> 2 ) << 5  ) | \
( blue  >> 3 ))

/*****************************************************************************/
//Some basic colors definitions.
#define BLACK               RGB565CONVERT(0,    0,      0)
#define BRIGHTBLUE          RGB565CONVERT(0,    0,      255)
#define BRIGHTGREEN         RGB565CONVERT(0,    255,    0)
#define BRIGHTCYAN          RGB565CONVERT(0,    255,    255)
#define BRIGHTRED           RGB565CONVERT(255,  0,      0)
#define BRIGHTMAGENTA       RGB565CONVERT(255,  0,      255)
#define BRIGHTYELLOW        RGB565CONVERT(255,  255,    0)
#define BLUE                RGB565CONVERT(0,    0,      128)
#define GREEN               RGB565CONVERT(0,    128,    0)
#define CYAN                RGB565CONVERT(0,    128,    128)
#define RED                 RGB565CONVERT(128,  0,      0)
#define MAGENTA             RGB565CONVERT(128,  0,      128)
#define BROWN               RGB565CONVERT(255,  128,    0)
#define LIGHTGRAY           RGB565CONVERT(128,  128,    128)
#define DARKGRAY            RGB565CONVERT(64,   64,     64)
#define LIGHTBLUE           RGB565CONVERT(128,  128,    255)
#define LIGHTGREEN          RGB565CONVERT(128,  255,    128)
#define LIGHTCYAN           RGB565CONVERT(128,  255,    255)
#define LIGHTRED            RGB565CONVERT(255,  128,    128)
#define LIGHTMAGENTA        RGB565CONVERT(255,  128,    255)
#define YELLOW              RGB565CONVERT(255,  255,    128)
#define WHITE               RGB565CONVERT(255,  255,    255)
                            
#define GRAY0       	    RGB565CONVERT(224,  224,    224)
#define GRAY1         	    RGB565CONVERT(192,  192,    192)   
#define GRAY2               RGB565CONVERT(160,  160,    160)   
#define GRAY3               RGB565CONVERT(128,  128,    128)
#define GRAY4               RGB565CONVERT(96,   96,     96)
#define GRAY5               RGB565CONVERT(64,   64,     64)
#define GRAY6	            RGB565CONVERT(32,   32,     32)

#define SELCOLOR	        RGB565CONVERT(255,   128,     64)
#define DESELCOLOR	        RGB565CONVERT(236,   233,     216)

/********************************************************************************************************/
// Line Types
#define SOLID_LINE         0
#define DOTTED_LINE        1
#define DASHED_LINE        2

/*******************************************************************************************************/
// Line Width
#define NORMAL_LINE        0
#define THICK_LINE         1

/********************************************************************************************************/
// Form Types
#define TYPE_SCR               0
#define TYPE_WIN1              1
#define TYPE_WIN2              2

/*******************************************************************************************************/
// Object codes
#define TEXTBOX_CODE           1
#define BUTTON_CODE            2
#define NEEDLE_CODE            3
#define NUMBERBOX_CODE         4
#define SLIDER_CODE            5
#define CHART_CODE             6
#define BARGRAPH_CODE          7
#define PICTUREBOX_CODE        8
#define IMAGE_CODE             9
#define SHAPE_CODE             10
#define FORM_CODE              11

/********************************************************************************************************/
// Shape codes
#define Shape_Line             0
#define Shape_Rectangle        1
#define Shape_Bevel            2
#define Shape_Circle           3
#define Shape_FBevel           4
#define Shape_FCircle          5
#define Shape_FRectangle       6

/********************************************************************************************************/
// Object Redraw modes                 
#define REDRAW_NO                     0			             
#define REDRAW_YES                    1					     

/*******************************************************************************************************/
// Object Property Value Types     
#define PROVAR_BYTE                   0			             
#define PROVAR_WORD                   1 			                 
#define PROVAR_DWORD                  2 			                 
#define PROVAR_STRING                 3

/*************************************************************************************************************/
// Form (Screen/Window) Properties postions and indexs

#define FORM_PRO_CODE              0
#define FORM_PRO_ID                1
#define FORM_PRO_LEFT              2
#define FORM_PRO_TOP               4
#define FORM_PRO_WIDTH             6
#define FORM_PRO_HEIGHT            8
#define FORM_PRO_TYPE              10
#define FORM_PRO_STYLE             11
#define FORM_PRO_BACKSTYLE         12
#define FORM_PRO_BORDERSTYLE       13
#define FORM_PRO_UIMODE            14
#define FORM_PRO_BGBITMAP          16
#define FORM_PRO_BACKCOLOR         18
#define FORM_PRO_BORDERCOLOR       20
#define FORM_PRO_TRANSCOLOR        22
#define FORM_PRO_OFFSETX           24
#define FORM_PRO_OFFSETY           25

/*************************************************************************************************************/
// Button Properties postions and indexs

#define BUTTON_PRO_CODE              0
#define BUTTON_PRO_ID                1
#define BUTTON_PRO_LEFT              2
#define BUTTON_PRO_TOP               4
#define BUTTON_PRO_WIDTH             6
#define BUTTON_PRO_HEIGHT            8
#define BUTTON_PRO_STYLE             10
#define BUTTON_PRO_TYPE              11
#define BUTTON_PRO_FONT              12
#define BUTTON_PRO_ALIGNMENT         13
#define BUTTON_PRO_ALPHARATIO        14
#define BUTTON_PRO_OFFSETX           15
#define BUTTON_PRO_OFFSETY           16
#define BUTTON_PRO_UPBITMAPID        17
#define BUTTON_PRO_DOWNBITMAPID      19
#define BUTTON_PRO_DISABLEBITMAPID   21
#define BUTTON_PRO_LABELCOLOR        23
#define BUTTON_PRO_ALPHACOLOR        25
#define BUTTON_PRO_TOUCHZONE         27
#define BUTTON_PRO_TZOFFSET          28
#define BUTTON_PRO_SOUNDEVENT        29
#define BUTTON_PRO_NOTIFYHOSTEVENT   30
#define BUTTON_PRO_TOGGLEEVENT       31
#define BUTTON_PRO_LABELPOSX         32
#define BUTTON_PRO_LABELPOSY         33
#define BUTTON_PRO_FUNCODE           34
#define BUTTON_PRO_FUNVAL0           35
#define BUTTON_PRO_FUNVAL1           36
#define BUTTON_PRO_FUNVAL2           37
#define BUTTON_PRO_FUNVAL3           38
#define BUTTON_PRO_FUNVAL4           39
#define BUTTON_PRO_FUNVAL5           40
#define BUTTON_PRO_FUNVAL6           41
#define BUTTON_PRO_FUNVAL7           42
#define BUTTON_PRO_VALUE             43
#define BUTTON_PRO_BEEPDURATION      45
#define BUTTON_PRO_BORDERSTYLE       46
#define BUTTON_PRO_BORDERCOLOR       47
#define BUTTON_PRO_INACTIVEBGCOLOR   49
#define BUTTON_PRO_ACTIVEBGCOLOR     51
#define BUTTON_PRO_ACTIVELABELCOLOR  53
#define BUTTON_PRO_TEXT              64

/*************************************************************************************************************/
// BarGraph Properties postions and indexs

#define BARGRAPH_PRO_CODE              0
#define BARGRAPH_PRO_ID                1
#define BARGRAPH_PRO_LEFT              2
#define BARGRAPH_PRO_TOP               4
#define BARGRAPH_PRO_WIDTH             6
#define BARGRAPH_PRO_HEIGHT            8
#define BARGRAPH_PRO_STYLE             10
#define BARGRAPH_PRO_TYPE              11
#define BARGRAPH_PRO_ORIENTATION       12
#define BARGRAPH_PRO_BORDERSTYLE       13
#define BARGRAPH_PRO_BACKSTYLE         14
#define BARGRAPH_PRO_SEGCOUNT          15
#define BARGRAPH_PRO_SEGSPACE          17
#define BARGRAPH_PRO_BACKCOLOR         18
#define BARGRAPH_PRO_FORECOLOR         20
#define BARGRAPH_PRO_BORDERCOLOR       22
#define BARGRAPH_PRO_OFFSETX           24
#define BARGRAPH_PRO_OFFSETY           25
#define BARGRAPH_PRO_OFFBITMAPID       26
#define BARGRAPH_PRO_ON1BITMAPID       28
#define BARGRAPH_PRO_ON2BITMAPID       30
#define BARGRAPH_PRO_TOUCHZONE         32
#define BARGRAPH_PRO_TZOFFSET          33
#define BARGRAPH_PRO_SOUNDEVENT        34
#define BARGRAPH_PRO_NOTIFYHOSTEVENT   35
#define BARGRAPH_PRO_VALUE             36
#define BARGRAPH_PRO_BITMAPINDEX       38
#define BARGRAPH_PRO_FUNCODE           39
#define BARGRAPH_PRO_FUNVAL0           40
#define BARGRAPH_PRO_FUNVAL1           41
#define BARGRAPH_PRO_FUNVAL2           42
#define BARGRAPH_PRO_FUNVAL3           43
#define BARGRAPH_PRO_FUNVAL4           44
#define BARGRAPH_PRO_FUNVAL5           45
#define BARGRAPH_PRO_FUNVAL6           46
#define BARGRAPH_PRO_FUNVAL7           47
#define BARGRAPH_PRO_BEEPDURATION      48

/*************************************************************************************************************/
// Chart Properties postions and indexs

#define CHART_PRO_CODE              0
#define CHART_PRO_ID                1
#define CHART_PRO_LEFT              2
#define CHART_PRO_TOP               4
#define CHART_PRO_WIDTH             6
#define CHART_PRO_HEIGHT            8
#define CHART_PRO_STYLE             10
#define CHART_PRO_TYPE              11
#define CHART_PRO_TRACECOUNT        12
#define CHART_PRO_GRIDSTYLE         13
#define CHART_PRO_PENWIDTH          14
#define CHART_PRO_BORDERSTYLE       15
#define CHART_PRO_XMAX              16
#define CHART_PRO_YMAX              18
#define CHART_PRO_XSCALE            20
#define CHART_PRO_YSCALE            21
#define CHART_PRO_XGRID             22
#define CHART_PRO_YGRID             23
#define CHART_PRO_OFFSETX           24
#define CHART_PRO_OFFSETY           25
#define CHART_PRO_BACKCOLOR         26
#define CHART_PRO_BORDERCOLOR       28
#define CHART_PRO_GRIDCOLOR         30
#define CHART_PRO_TRACE0COLOR       32
#define CHART_PRO_TRACE1COLOR       34
#define CHART_PRO_TRACE2COLOR       36
#define CHART_PRO_TRACE3COLOR       38
#define CHART_PRO_TOUCHZONE         40
#define CHART_PRO_TZOFFSET          41
#define CHART_PRO_SOUNDEVENT        42
#define CHART_PRO_NOTIFYHOSTEVENT   43
#define CHART_PRO_FUNCODE           44
#define CHART_PRO_FUNVAL0           45
#define CHART_PRO_FUNVAL1           46
#define CHART_PRO_FUNVAL2           47
#define CHART_PRO_FUNVAL3           48
#define CHART_PRO_FUNVAL4           49
#define CHART_PRO_FUNVAL5           50
#define CHART_PRO_FUNVAL6           51
#define CHART_PRO_FUNVAL7           52
#define CHART_PRO_BEEPDURATION      53


/*************************************************************************************************************/
// Image Properties postions and indexs

#define IMAGE_PRO_CODE              0
#define IMAGE_PRO_ID                1
#define IMAGE_PRO_LEFT              2
#define IMAGE_PRO_TOP               4
#define IMAGE_PRO_WIDTH             6
#define IMAGE_PRO_HEIGHT            8
#define IMAGE_PRO_STYLE             10
#define IMAGE_PRO_MOVE              11
#define IMAGE_PRO_SPEED             12
#define IMAGE_PRO_FRAMECOUNT        13
#define IMAGE_PRO_VALUE             14
#define IMAGE_PRO_TOUCHZONE         15
#define IMAGE_PRO_TZOFFSET          16
#define IMAGE_PRO_SOUNDEVENT        17
#define IMAGE_PRO_NOTIFYHOSTEVENT   18
#define IMAGE_PRO_FUNCODE           19
#define IMAGE_PRO_FUNVAL0           20
#define IMAGE_PRO_FUNVAL1           21
#define IMAGE_PRO_FUNVAL2           22
#define IMAGE_PRO_FUNVAL3           23
#define IMAGE_PRO_FUNVAL4           24
#define IMAGE_PRO_FUNVAL5           25
#define IMAGE_PRO_FUNVAL6           26
#define IMAGE_PRO_FUNVAL7           27
#define IMAGE_PRO_SPECIALEVENT      28
#define IMAGE_PRO_BEEPDURATION      29

/*************************************************************************************************************/
// Needle Properties postions and indexs

#define NEEDLE_PRO_CODE              0
#define NEEDLE_PRO_ID                1
#define NEEDLE_PRO_LEFT              2
#define NEEDLE_PRO_TOP               4
#define NEEDLE_PRO_WIDTH             6
#define NEEDLE_PRO_HEIGHT            8
#define NEEDLE_PRO_STYLE             10
#define NEEDLE_PRO_TYPE              11
#define NEEDLE_PRO_MINANGLE          12
#define NEEDLE_PRO_MAXANGLE          13
#define NEEDLE_PRO_LENGTH            14
#define NEEDLE_PRO_POSX              15
#define NEEDLE_PRO_POSY              16
#define NEEDLE_PRO_PASTESTATE        17
#define NEEDLE_PRO_DRAWCOLOR         18
#define NEEDLE_PRO_CLEARCOLOR        20
#define NEEDLE_PRO_BGBITMAP          22
#define NEEDLE_PRO_TOUCHZONE         24
#define NEEDLE_PRO_TZOFFSET          25
#define NEEDLE_PRO_SOUNDEVENT        26
#define NEEDLE_PRO_NOTIFYHOSTEVENT   27
#define NEEDLE_PRO_FUNCODE           28
#define NEEDLE_PRO_FUNVAL0           29
#define NEEDLE_PRO_FUNVAL1           30
#define NEEDLE_PRO_FUNVAL2           31
#define NEEDLE_PRO_FUNVAL3           32
#define NEEDLE_PRO_FUNVAL4           33
#define NEEDLE_PRO_FUNVAL5           34
#define NEEDLE_PRO_FUNVAL6           35
#define NEEDLE_PRO_FUNVAL7           36
#define NEEDLE_PRO_VALUE             37
#define NEEDLE_PRO_BUFFERINDEX       39
#define NEEDLE_PRO_BEEPDURATION      42

/*************************************************************************************************************/
// NumberBox Properties postions and indexs

#define NUMBERBOX_PRO_CODE              0
#define NUMBERBOX_PRO_ID                1
#define NUMBERBOX_PRO_LEFT              2
#define NUMBERBOX_PRO_TOP               4
#define NUMBERBOX_PRO_WIDTH             6
#define NUMBERBOX_PRO_HEIGHT            8
#define NUMBERBOX_PRO_STYLE             10
#define NUMBERBOX_PRO_TYPE              11
#define NUMBERBOX_PRO_DIGITCOUNT        12
#define NUMBERBOX_PRO_DECIMALPOINT      13
#define NUMBERBOX_PRO_LEADINGZEROS      14
#define NUMBERBOX_PRO_OFFSETX           15
#define NUMBERBOX_PRO_OFFSETY           16
#define NUMBERBOX_PRO_D0BMID            17
#define NUMBERBOX_PRO_D1BMID            19
#define NUMBERBOX_PRO_D2BMID            21
#define NUMBERBOX_PRO_D3BMID            23
#define NUMBERBOX_PRO_D4BMID            25
#define NUMBERBOX_PRO_D5BMID            27
#define NUMBERBOX_PRO_D6BMID            29
#define NUMBERBOX_PRO_D7BMID            31
#define NUMBERBOX_PRO_D8BMID            33
#define NUMBERBOX_PRO_D9BMID            35
#define NUMBERBOX_PRO_D10BMID           37
#define NUMBERBOX_PRO_D11BMID           39
#define NUMBERBOX_PRO_D12BMID           41
#define NUMBERBOX_PRO_D13BMID           43
#define NUMBERBOX_PRO_TOUCHZONE         45
#define NUMBERBOX_PRO_TZOFFSET          46
#define NUMBERBOX_PRO_SOUNDEVENT        47
#define NUMBERBOX_PRO_NOTIFYHOSTEVENT   48
#define NUMBERBOX_PRO_FUNCODE           49
#define NUMBERBOX_PRO_FUNVAL0           50
#define NUMBERBOX_PRO_FUNVAL1           51
#define NUMBERBOX_PRO_FUNVAL2           52
#define NUMBERBOX_PRO_FUNVAL3           53
#define NUMBERBOX_PRO_FUNVAL4           54
#define NUMBERBOX_PRO_FUNVAL5           55
#define NUMBERBOX_PRO_FUNVAL6           56
#define NUMBERBOX_PRO_FUNVAL7           57
#define NUMBERBOX_PRO_VALUE             58
#define NUMBERBOX_PRO_BEEPDURATION      62

/*************************************************************************************************************/
// PictureBox Properties postions and indexs

#define PICTUREBOX_PRO_CODE              0
#define PICTUREBOX_PRO_ID                1
#define PICTUREBOX_PRO_LEFT              2
#define PICTUREBOX_PRO_TOP               4
#define PICTUREBOX_PRO_WIDTH             6
#define PICTUREBOX_PRO_HEIGHT            8
#define PICTUREBOX_PRO_BACKSTYLE         10
#define PICTUREBOX_PRO_DRAWTYPE          11
#define PICTUREBOX_PRO_DRAWWIDTH         12
#define PICTUREBOX_PRO_FONT              13
#define PICTUREBOX_PRO_BORDERSTYLE       14
#define PICTUREBOX_PRO_BACKCOLOR         15
#define PICTUREBOX_PRO_FORECOLOR         17
#define PICTUREBOX_PRO_BORDERCOLOR       19
#define PICTUREBOX_PRO_OFFSETX           21
#define PICTUREBOX_PRO_OFFSETY           22
#define PICTUREBOX_PRO_BGBITMAPID        23
#define PICTUREBOX_PRO_TOUCHZONE         25
#define PICTUREBOX_PRO_TZOFFSET          26
#define PICTUREBOX_PRO_SOUNDEVENT        27
#define PICTUREBOX_PRO_NOTIFYHOSTEVENT   28
#define PICTUREBOX_PRO_SKETCHEVENT       29
#define PICTUREBOX_PRO_FUNCODE           30
#define PICTUREBOX_PRO_FUNVAL0           31
#define PICTUREBOX_PRO_FUNVAL1           32
#define PICTUREBOX_PRO_FUNVAL2           33
#define PICTUREBOX_PRO_FUNVAL3           34
#define PICTUREBOX_PRO_FUNVAL4           35
#define PICTUREBOX_PRO_FUNVAL5           36
#define PICTUREBOX_PRO_FUNVAL6           37
#define PICTUREBOX_PRO_FUNVAL7           38
#define PICTUREBOX_PRO_BEEPDURATION      39

/*************************************************************************************************************/
// Shape Properties postions and indexs

#define SHAPE_PRO_CODE              0
#define SHAPE_PRO_ID                1
#define SHAPE_PRO_LEFT              2
#define SHAPE_PRO_TOP               4
#define SHAPE_PRO_WIDTH             6
#define SHAPE_PRO_HEIGHT            8
#define SHAPE_PRO_STYLE             10
#define SHAPE_PRO_DRAWTYPE          11
#define SHAPE_PRO_DRAWWIDTH         12
#define SHAPE_PRO_BORDERSTYLE       13
#define SHAPE_PRO_FORECOLOR         14
#define SHAPE_PRO_BORDERCOLOR       16
#define SHAPE_PRO_OFFSETX           18
#define SHAPE_PRO_OFFSETY           19
#define SHAPE_PRO_TOUCHZONE         20
#define SHAPE_PRO_TZOFFSET          21
#define SHAPE_PRO_SOUNDEVENT        22
#define SHAPE_PRO_NOTIFYHOSTEVENT   23
#define SHAPE_PRO_FUNCODE           24
#define SHAPE_PRO_FUNVAL0           25
#define SHAPE_PRO_FUNVAL1           26
#define SHAPE_PRO_FUNVAL2           27
#define SHAPE_PRO_FUNVAL3           28
#define SHAPE_PRO_FUNVAL4           29
#define SHAPE_PRO_FUNVAL5           30
#define SHAPE_PRO_FUNVAL6           31
#define SHAPE_PRO_FUNVAL7           32
#define SHAPE_PRO_BEEPDURATION      33

/*************************************************************************************************************/
// Slider Properties postions and indexs

#define SLIDER_PRO_CODE              0
#define SLIDER_PRO_ID                1
#define SLIDER_PRO_LEFT              2
#define SLIDER_PRO_TOP               4
#define SLIDER_PRO_WIDTH             6
#define SLIDER_PRO_HEIGHT            8
#define SLIDER_PRO_STYLE             10
#define SLIDER_PRO_ORIENTATION       11
#define SLIDER_PRO_TICKSTYLE         12
#define SLIDER_PRO_BORDERSTYLE       13
#define SLIDER_PRO_RANGE             14
#define SLIDER_PRO_CHANGE            16
#define SLIDER_PRO_TICKFREQ          17
#define SLIDER_PRO_THUMBWIDTH        18
#define SLIDER_PRO_THUMBHEIGHT       19
#define SLIDER_PRO_OFFSETX           20
#define SLIDER_PRO_OFFSETY           21
#define SLIDER_PRO_TRACKBITMAPID     22
#define SLIDER_PRO_ITHUMBBITMAPID    24
#define SLIDER_PRO_ATHUMBBITMAPID    26
#define SLIDER_PRO_BACKCOLOR         28
#define SLIDER_PRO_FORECOLOR         30
#define SLIDER_PRO_BORDERCOLOR       32
#define SLIDER_PRO_TOUCHZONE         34
#define SLIDER_PRO_TZOFFSET          35
#define SLIDER_PRO_SOUNDEVENT        36
#define SLIDER_PRO_NOTIFYHOSTEVENT   37
#define SLIDER_PRO_MOVEEVENT         38
#define SLIDER_PRO_FUNCODE           39
#define SLIDER_PRO_FUNVAL0           40
#define SLIDER_PRO_FUNVAL1           41
#define SLIDER_PRO_FUNVAL2           42
#define SLIDER_PRO_FUNVAL3           43
#define SLIDER_PRO_FUNVAL4           44
#define SLIDER_PRO_FUNVAL5           45
#define SLIDER_PRO_FUNVAL6           46
#define SLIDER_PRO_FUNVAL7           47
#define SLIDER_PRO_VALUE             48
#define SLIDER_PRO_BITMAPINDEX       52
#define SLIDER_PRO_BEEPDURATION      53

/*************************************************************************************************************/
// TextBox Properties postions and indexs

#define TEXTBOX_PRO_CODE              0
#define TEXTBOX_PRO_ID                1
#define TEXTBOX_PRO_LEFT              2
#define TEXTBOX_PRO_TOP               4
#define TEXTBOX_PRO_WIDTH             6
#define TEXTBOX_PRO_HEIGHT            8
#define TEXTBOX_PRO_STYLE             10
#define TEXTBOX_PRO_ALIGNMENT         11
#define TEXTBOX_PRO_FONT              12
#define TEXTBOX_PRO_BORDERSTYLE       13
#define TEXTBOX_PRO_BACKCOLOR         14
#define TEXTBOX_PRO_FORECOLOR         16
#define TEXTBOX_PRO_BORDERCOLOR       18
#define TEXTBOX_PRO_OFFSETX           20
#define TEXTBOX_PRO_OFFSETY           21
#define TEXTBOX_PRO_TOUCHZONE         22
#define TEXTBOX_PRO_TZOFFSET          23
#define TEXTBOX_PRO_SOUNDEVENT        24
#define TEXTBOX_PRO_NOTIFYHOSTEVENT   25
#define TEXTBOX_PRO_FUNCODE           26
#define TEXTBOX_PRO_FUNVAL0           27
#define TEXTBOX_PRO_FUNVAL1           28
#define TEXTBOX_PRO_FUNVAL2           29
#define TEXTBOX_PRO_FUNVAL3           30
#define TEXTBOX_PRO_FUNVAL4           31
#define TEXTBOX_PRO_FUNVAL5           32
#define TEXTBOX_PRO_FUNVAL6           33
#define TEXTBOX_PRO_FUNVAL7           34
#define TEXTBOX_PRO_VALUE             35
#define TEXTBOX_PRO_SPECIALEVENT      36
#define TEXTBOX_PRO_BEEPDURATION      37
#define TEXTBOX_PRO_TEXT              64

