/*****************************************************************************
 * GUI Commands driver for SegeNT
 *****************************************************************************
 * FileName:        ObjCommands.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar         4/16/2014
 *****************************************************************************/
#include "GUICommands.h"
#include "RS232.h"

/*************************************************************************************************************/
void GuiCmd_Load_Form(BYTE ID)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = LOAD_FORM;
  RXCount = 1;
  TXCount = LOAD_FORM_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Draw_Form(BYTE ID)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = DRAW_FORM;
  RXCount = 1;
  TXCount = DRAW_FORM_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_View_Form(BYTE ID, BYTE Value)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = VIEW_FORM;
  RXCount = 1;
  TXCount = VIEW_FORM_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = Value;
  TXBuffer[6] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Move_Form(BYTE ID, WORD X, WORD Y)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = MOVE_FORM;
  RXCount = 1;
  TXCount = MOVE_FORM_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X>>8)&0x00FF;
  TXBuffer[6] = (X)&0x00FF;
  TXBuffer[7] = (Y>>8)&0x00FF;
  TXBuffer[8] = (Y)&0x00FF;
  TXBuffer[9] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
BYTE GuiCmd_Get_ActiveScrID()
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_ACTIVESCRID;
  RXCount = GET_ACTIVESCRID_RXNOB + 3;
  TXCount = GET_ACTIVESCRID_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
       
  CmdInProgress = 0;                         // Clear Command In Progress Flag

  // Return Active Screen ID Number
  return RXBuffer[2];           
}

/****************************************************************************/
BYTE GuiCmd_Get_ActiveWin1ID()
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_ACTIVEWIN1ID;
  RXCount = GET_ACTIVEWIN1ID_RXNOB + 3;
  TXCount = GET_ACTIVEWIN1ID_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
      
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  // Return Active Window1 ID Number
  return RXBuffer[2];           
}

/****************************************************************************/
BYTE GuiCmd_Get_ActiveWin2ID()
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_ACTIVEWIN2ID;
  RXCount = GET_ACTIVEWIN2ID_RXNOB + 3;
  TXCount = GET_ACTIVEWIN2ID_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
       
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  // Return Active Window2 ID Number
  return RXBuffer[2];                   
}

/*************************************************************************************************************/
void GuiCmd_Enable_UI(BYTE Value)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = ENABLE_UI;
  RXCount = 1;
  TXCount = ENABLE_UI_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Value;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Enable_Form(BYTE ID, BYTE Value)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = ENABLE_FORM;
  RXCount = 1;
  TXCount = ENABLE_FORM_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = Value;
  TXBuffer[6] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
void GuiCmd_Get_UIMsg()
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_UIMSG;
  RXCount = GET_UIMSG_RXNOB + 3;
  TXCount = GET_UIMSG_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();

  // Get Simple Touch Message
  UI_Msg.Status = RXBuffer[2];
  UI_Msg.Type = RXBuffer[3];
  UI_Msg.Code = RXBuffer[4];
  UI_Msg.ID = RXBuffer[5];
  UI_Msg.Value = (WORD)256*RXBuffer[6] + RXBuffer[7] ;  
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
void GuiCmd_Get_UIMsgAdv()
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_UIMSGADV;
  RXCount = GET_UIMSGADV_RXNOB + 3;
  TXCount = GET_UIMSGADV_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();

  // Get Advanced Touch Message
  UI_Msg.Status = RXBuffer[2];
  UI_Msg.Type = RXBuffer[3];
  UI_Msg.Code = RXBuffer[4];
  UI_Msg.ID = RXBuffer[5];
  UI_Msg.Value = (WORD)256*RXBuffer[6] + RXBuffer[7];
  UI_Msg.TStatus = RXBuffer[8];  
  UI_Msg.TX = (WORD)256*RXBuffer[9] + RXBuffer[10];
  UI_Msg.TY = (WORD)256*RXBuffer[11] + RXBuffer[12];
       
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
BYTE GuiCmd_Get_UIStatus()
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_UISTATUS;
  RXCount = GET_UISTATUS_RXNOB + 3;
  TXCount = GET_UISTATUS_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  // Return UI Status
  return RXBuffer[2];                   
}

/****************************************************************************/
BYTE GuiCmd_Get_FormStatus(BYTE ID)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_FORMSTATUS;
  RXCount = GET_FORMSTATUS_RXNOB + 3;
  TXCount = GET_FORMSTATUS_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag

  // Return Form Status
  return RXBuffer[2];                    
}

/****************************************************************************/
// Return Byte Propery value 
BYTE GuiCmd_Get_ObjProperty_Byte(BYTE Code, BYTE ID, BYTE ProIndex)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_OBJPROPERTY;
  RXCount = GET_OBJPROPERTY_RXNOB + 3;
  TXCount = GET_OBJPROPERTY_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  return  RXBuffer[2];        
}

/****************************************************************************/
// Return Word Propery value 
WORD GuiCmd_Get_ObjProperty_Word(BYTE Code, BYTE ID, BYTE ProIndex)
{
  WORD_VAL Temp;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_OBJPROPERTY;
  RXCount = GET_OBJPROPERTY_RXNOB + 3;
  TXCount = GET_OBJPROPERTY_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();

  Temp.v[1] = RXBuffer[2];
  Temp.v[0] = RXBuffer[3];
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  return  Temp.Val;        
}

/****************************************************************************/
// Return DWord Propery value 
DWORD GuiCmd_Get_ObjProperty_DWord(BYTE Code, BYTE ID, BYTE ProIndex)
{
  DWORD_VAL Temp;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = GET_OBJPROPERTY;
  RXCount = GET_OBJPROPERTY_RXNOB + 3;
  TXCount = GET_OBJPROPERTY_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();

  Temp.v[3] = RXBuffer[2];    //MSB
  Temp.v[2] = RXBuffer[3];
  Temp.v[1] = RXBuffer[4];
  Temp.v[0] = RXBuffer[5];    //LSB
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  return  Temp.Val;        
}

/****************************************************************************/
// Set Property Value Byte
void GuiCmd_Set_ObjProperty_Byte(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, BYTE Value)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = SET_OBJPROPERTY;
  RXCount = 1;
  TXCount = SET_OBJPROPERTY_TXNOB + 8;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = Mode;
  TXBuffer[8] = Value;
  TXBuffer[9] = 0;
  TXBuffer[10] = 0;
  TXBuffer[11] = 0;
  TXBuffer[12] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
// Set Property Value Word
void GuiCmd_Set_ObjProperty_Word(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, WORD Value)
{
  WORD_VAL Temp;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = SET_OBJPROPERTY;
  RXCount = 1;
  TXCount = SET_OBJPROPERTY_TXNOB + 8;

  CmdTimeOut = 10;                          // 2 Sec time out

  Temp.Val = Value;

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = Mode;
  TXBuffer[8] = Temp.v[1];
  TXBuffer[9] = Temp.v[0];
  TXBuffer[10] = 0;
  TXBuffer[11] = 0;
  TXBuffer[12] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
// Set Property Value DWord
void GuiCmd_Set_ObjProperty_DWord(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, DWORD Value)
{
  WORD_VAL Temp;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = SET_OBJPROPERTY;
  RXCount = 1;
  TXCount = SET_OBJPROPERTY_TXNOB + 8;

  CmdTimeOut = 10;                          // 2 Sec time out

  Temp.Val = Value;

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = Mode;
  TXBuffer[8] = Temp.v[3];
  TXBuffer[9] = Temp.v[2];
  TXBuffer[10] = Temp.v[1];
  TXBuffer[11] = Temp.v[0];
  TXBuffer[12] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/****************************************************************************/
// Set Property Value String
void GuiCmd_Set_ObjProperty_String(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, BYTE* pText)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = SET_OBJPROPERTY;
  RXCount = 1;
  TXCount = SET_OBJPROPERTY_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  // First we need to know how many characters so we can set TXCount
  // and at the same time updating the TXBuffer
  for(i=0; i<64; i++)
   {
     TXBuffer[8+i] = *pText;
     if (*pText == 0)
      {
        TXCount = TXCount + i + 1;
        break;
      }
     pText++;
   } 

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = ProIndex;
  TXBuffer[7] = Mode;
  TXBuffer[TXCount - 1] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
          
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Redraw_Form(BYTE ID)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = REDRAW_FORM;
  RXCount = 1;
  TXCount = REDRAW_FORM_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Redraw_Object(BYTE Code, BYTE ID)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = REDRAW_OBJECT;
  RXCount = 1;
  TXCount = REDRAW_OBJECT_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = Code;
  TXBuffer[5] = ID;
  TXBuffer[6] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Chart_AddPoint(BYTE ID, WORD X0, WORD Y0, WORD X1, WORD Y1, WORD X2, WORD Y2, WORD X3, WORD Y3)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = CHART_ADDPOINT;
  RXCount = 1;
  TXCount = CHART_ADDPOINT_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X0>>8)&0x00FF;
  TXBuffer[6] = (X0)&0x00FF;
  TXBuffer[7] = (Y0>>8)&0x00FF;
  TXBuffer[8] = (Y0)&0x00FF;
  TXBuffer[9] = (X1>>8)&0x00FF;
  TXBuffer[10] = (X1)&0x00FF;
  TXBuffer[11] = (Y1>>8)&0x00FF;
  TXBuffer[12] = (Y1)&0x00FF;
  TXBuffer[13] = (X2>>8)&0x00FF;
  TXBuffer[14] = (X2)&0x00FF;
  TXBuffer[15] = (Y2>>8)&0x00FF;
  TXBuffer[16] = (Y2)&0x00FF;
  TXBuffer[17] = (X3>>8)&0x00FF;
  TXBuffer[18] = (X3)&0x00FF;
  TXBuffer[19] = (Y3>>8)&0x00FF;
  TXBuffer[20] = (Y3)&0x00FF;
  TXBuffer[21] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Chart_Clear(BYTE ID)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = CHART_CLEAR;
  RXCount = 1;
  TXCount = CHART_CLEAR_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Chart_HCL(BYTE ID, WORD Y, WORD Color)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = CHART_HCL;
  RXCount = 1;
  TXCount = CHART_HCL_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (Y>>8)&0x00FF;
  TXBuffer[6] = (Y)&0x00FF;
  TXBuffer[7] = (Color>>8)&0x00FF;
  TXBuffer[8] = (Color)&0x00FF;
  TXBuffer[9] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Chart_VCL(BYTE ID, WORD X, WORD Color)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = CHART_VCL;
  RXCount = 1;
  TXCount = CHART_VCL_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X>>8)&0x00FF;
  TXBuffer[6] = (X)&0x00FF;
  TXBuffer[7] = (Color>>8)&0x00FF;
  TXBuffer[8] = (Color)&0x00FF;
  TXBuffer[9] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_TextBox_Clear(BYTE ID)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = TEXTBOX_CLEAR;
  RXCount = 1;
  TXCount = TEXTBOX_CLEAR_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_TextBox_State(BYTE ID, BYTE Value)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = TEXTBOX_STATE;
  RXCount = 1;
  TXCount = TEXTBOX_STATE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = Value;
  TXBuffer[6] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_TextBox_Text(BYTE ID, BYTE* pText)
{
  BYTE i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = TEXTBOX_TEXT;
  RXCount = 1;
  TXCount = TEXTBOX_TEXT_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  // First we need to know how many characters so we can set TXCount
  // and at the same time updating the TXBuffer
  for(i=0; i<64; i++)
   {
     TXBuffer[5+i] = *pText;
     if (*pText == 0)
      {
        TXCount = TXCount + i + 1;
        break;
      }
     pText++;
   } 

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[TXCount - 1] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_TextBox_Number(BYTE ID, BYTE LZ, BYTE DP, DWORD Value)
{
  DWORD_VAL Temp;
  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = TEXTBOX_NUMBER;
  RXCount = 1;
  TXCount = TEXTBOX_NUMBER_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  Temp.Val = Value;

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = LZ;
  TXBuffer[6] = DP;
  TXBuffer[7] = Temp.v[3];
  TXBuffer[8] = Temp.v[2];
  TXBuffer[9] = Temp.v[1];
  TXBuffer[10] = Temp.v[0];
  TXBuffer[11] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_BarGraph_Value(BYTE ID, WORD Value, BYTE BitmapIndex)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = BARGRAPH_VALUE;
  RXCount = 1;
  TXCount = BARGRAPH_VALUE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (Value>>8)&0x00FF;
  TXBuffer[6] = (Value)&0x00FF;
  TXBuffer[7] = BitmapIndex;
  TXBuffer[8] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Button_State(BYTE ID, BYTE Value)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = BUTTON_STATE;
  RXCount = 1;
  TXCount = BUTTON_STATE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = Value;
  TXBuffer[6] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_NumberBox_Value(BYTE ID, DWORD Value)
{
  DWORD_VAL Temp;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = NUMBERBOX_VALUE;
  RXCount = 1;
  TXCount = NUMBERBOX_VALUE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  Temp.Val = Value;

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = Temp.v[3];
  TXBuffer[6] = Temp.v[2];
  TXBuffer[7] = Temp.v[1];
  TXBuffer[8] = Temp.v[0];
  TXBuffer[9] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Needle_Value(BYTE ID, WORD Value)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = NEEDLE_VALUE;
  RXCount = 1;
  TXCount = NEEDLE_VALUE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (Value>>8)&0x00FF;
  TXBuffer[6] = (Value)&0x00FF;
  TXBuffer[7] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Slider_Value(BYTE ID, WORD Value)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = SLIDER_VALUE;
  RXCount = 1;
  TXCount = SLIDER_VALUE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (Value>>8)&0x00FF;
  TXBuffer[6] = (Value)&0x00FF;
  TXBuffer[7] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Clear(BYTE ID)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_CLEAR;
  RXCount = 1;
  TXCount = PICTUREBOX_CLEAR_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Bitmap(BYTE ID, WORD BitmapID, BYTE Rot, BYTE Mir, WORD X, WORD Y)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_BITMAP;
  RXCount = 1;
  TXCount = PICTUREBOX_BITMAP_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (BitmapID>>8)&0x00FF;
  TXBuffer[6] = (BitmapID)&0x00FF;
  TXBuffer[7] = Rot;
  TXBuffer[8] = Mir;
  TXBuffer[9] = (X>>8)&0x00FF;
  TXBuffer[10] = (X)&0x00FF;
  TXBuffer[11] = (Y>>8)&0x00FF;
  TXBuffer[12] = (Y)&0x00FF;
  TXBuffer[13] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Line(BYTE ID, WORD X1, WORD Y1, WORD X2, WORD Y2)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_LINE;
  RXCount = 1;
  TXCount = PICTUREBOX_LINE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X1>>8)&0x00FF;
  TXBuffer[6] = (X1)&0x00FF;
  TXBuffer[7] = (Y1>>8)&0x00FF;
  TXBuffer[8] = (Y1)&0x00FF;
  TXBuffer[9] = (X2>>8)&0x00FF;
  TXBuffer[10] = (X2)&0x00FF;
  TXBuffer[11] = (Y2>>8)&0x00FF;
  TXBuffer[12] = (Y2)&0x00FF;
  TXBuffer[13] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Rectangle(BYTE ID, WORD X1, WORD Y1, WORD X2, WORD Y2, BYTE Round, BYTE Filled)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_RECTANGLE;
  RXCount = 1;
  TXCount = PICTUREBOX_RECTANGLE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X1>>8)&0x00FF;
  TXBuffer[6] = (X1)&0x00FF;
  TXBuffer[7] = (Y1>>8)&0x00FF;
  TXBuffer[8] = (Y1)&0x00FF;
  TXBuffer[9] = (X2>>8)&0x00FF;
  TXBuffer[10] = (X2)&0x00FF;
  TXBuffer[11] = (Y2>>8)&0x00FF;
  TXBuffer[12] = (Y2)&0x00FF;
  TXBuffer[13] = Round;
  TXBuffer[14] = Filled;
  TXBuffer[15] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Circle(BYTE ID, WORD X0, WORD Y0, WORD Rad, BYTE Filled)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_CIRCLE;
  RXCount = 1;
  TXCount = PICTUREBOX_CIRCLE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X0>>8)&0x00FF;
  TXBuffer[6] = (X0)&0x00FF;
  TXBuffer[7] = (Y0>>8)&0x00FF;
  TXBuffer[8] = (Y0)&0x00FF;
  TXBuffer[9] = (Rad>>8)&0x00FF;
  TXBuffer[10] = (Rad)&0x00FF;
  TXBuffer[11] = Filled;
  TXBuffer[12] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_SetPixel(BYTE ID, WORD X0, WORD Y0)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_SETPIXEL;
  RXCount = 1;
  TXCount = PICTUREBOX_SETPIXEL_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X0>>8)&0x00FF;
  TXBuffer[6] = (X0)&0x00FF;
  TXBuffer[7] = (Y0>>8)&0x00FF;
  TXBuffer[8] = (Y0)&0x00FF;
  TXBuffer[9] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
WORD GuiCmd_PictureBox_GetPixel(BYTE ID, WORD X0, WORD Y0)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_GETPIXEL;
  RXCount = PICTUREBOX_GETPIXEL_RXNOB + 3;
  TXCount = PICTUREBOX_GETPIXEL_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X0>>8)&0x00FF;
  TXBuffer[6] = (X0)&0x00FF;
  TXBuffer[7] = (Y0>>8)&0x00FF;
  TXBuffer[8] = (Y0)&0x00FF;
  TXBuffer[9] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag 

  // Return Pixel Color
  return (WORD)256*RXBuffer[2] + RXBuffer[3];          
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_CopyArea(BYTE ID, WORD X, WORD Y, BYTE W, BYTE H)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_COPYAREA;
  RXCount = 1;
  TXCount = PICTUREBOX_COPYAREA_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X>>8)&0x00FF;
  TXBuffer[6] = (X)&0x00FF;
  TXBuffer[7] = (Y>>8)&0x00FF;
  TXBuffer[8] = (Y)&0x00FF;
  TXBuffer[9] = W;
  TXBuffer[10] = H;
  TXBuffer[11] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_PasteArea(BYTE ID, WORD X, WORD Y, BYTE W, BYTE H)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_PASTEAREA;
  RXCount = 1;
  TXCount = PICTUREBOX_PASTEAREA_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X>>8)&0x00FF;
  TXBuffer[6] = (X)&0x00FF;
  TXBuffer[7] = (Y>>8)&0x00FF;
  TXBuffer[8] = (Y)&0x00FF;
  TXBuffer[9] = W;
  TXBuffer[10] = H;
  TXBuffer[11] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Print(BYTE ID, WORD CurX, WORD CurY, BYTE* pText)
{
  WORD i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_PRINT;
  RXCount = 1;
  TXCount = PICTUREBOX_PRINT_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  // First we need to know how many characters so we can set TXCount
  // and at the same time updating the TXBuffer
  for(i=0; i<256; i++)
   {
     TXBuffer[9+i] = *pText;
     if (*pText == 0)
      {
        TXCount = TXCount + i + 1;
        break;
      }
     pText++;
   } 

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (CurX>>8)&0x00FF;
  TXBuffer[6] = (CurX)&0x00FF;
  TXBuffer[7] = (CurY>>8)&0x00FF;
  TXBuffer[8] = (CurY)&0x00FF;
  TXBuffer[TXCount - 1] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
// This command is the same as above but only print one character
void GuiCmd_PictureBox_PrintChar(BYTE ID, WORD CurX, WORD CurY, BYTE Char)
{
  WORD i;

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_PRINT;
  RXCount = 1;
  TXCount = PICTUREBOX_PRINT_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  // First we need to know how many characters so we can set TXCount
  // and at the same time updating the TXBuffer

  TXBuffer[9] = Char;
  TXBuffer[10] = 0;    // Termination
  TXCount = TXCount + 2;

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (CurX>>8)&0x00FF;
  TXBuffer[6] = (CurX)&0x00FF;
  TXBuffer[7] = (CurY>>8)&0x00FF;
  TXBuffer[8] = (CurY)&0x00FF;
  TXBuffer[TXCount - 1] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_PictureBox_Picture(BYTE ID, WORD X, WORD Y, WORD W, WORD H, WORD Block)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = PICTUREBOX_PICTURE;
  RXCount = 1;
  TXCount = PICTUREBOX_PICTURE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = (X>>8)&0x00FF;
  TXBuffer[6] = (X)&0x00FF;
  TXBuffer[7] = (Y>>8)&0x00FF;
  TXBuffer[8] = (Y)&0x00FF;
  TXBuffer[9] = (W>>8)&0x00FF;
  TXBuffer[10] = (W)&0x00FF;
  TXBuffer[11] = (H>>8)&0x00FF;
  TXBuffer[12] = (H)&0x00FF;
  TXBuffer[13] = (Block>>8)&0x00FF;
  TXBuffer[14] = (Block)&0x00FF;
  TXBuffer[15] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Animation_Play(BYTE ID)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = ANIMATION_PLAY;
  RXCount = 1;
  TXCount = ANIMATION_PLAY_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Animation_Stop(BYTE ID)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = ANIMATION_STOP;
  RXCount = 1;
  TXCount = ANIMATION_STOP_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

/*************************************************************************************************************/
void GuiCmd_Image_Value(BYTE ID, BYTE Value)
{

  CmdInProgress = 1;                         // Set Command In Progress Flag

  CmdCode = IMAGE_VALUE;
  RXCount = 1;
  TXCount = IMAGE_VALUE_TXNOB + 4;

  CmdTimeOut = 10;                          // 2 Sec time out

  TXBuffer[0] = SEGE_DEVID;
  TXBuffer[1] = ((TXCount - 4)>>8)&0x00FF;
  TXBuffer[2] = (TXCount - 4)&0x00FF;
  TXBuffer[3] = CmdCode;
  TXBuffer[4] = ID;
  TXBuffer[5] = Value;
  TXBuffer[6] = GetTXChecksum();
  
  // Wait for Sege to be Ready (wait for Ready line to be low)
  IsSegeReady();

  // Send Command
  Send_Command();

  // Wait for the response to be received
  IsRxDone();
         
  CmdInProgress = 0;                         // Clear Command In Progress Flag           
}

































