/*****************************************************************************
 * Objects Commands for SegeNT
 *****************************************************************************
 * FileName:        GUICommands.h
 * Dependencies:    
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar         4/16/2014   
 *****************************************************************************/
#include "MainDemo.h"

/*****************************************************************************/
// Global Variables

typedef struct {
    BYTE 			Status;	        // Message Status (Valid Event or Invalid Event)
    BYTE            Type;           // Event type (Press, Release...)    
    BYTE 			Code;		    // Object Code
    BYTE 			ID; 	        // Object ID
    WORD            Value;          // Object Value if it has value
    WORD            TStatus;        // Pen up or down
    WORD            TX;             // Touch X
    WORD            TY;             // Touch Y
} UI_MSG;
volatile UI_MSG UI_Msg;


/*****************************************************************************/
// GUI Command Codes

#define          LOAD_FORM                         100
#define          DRAW_FORM                         101
#define          VIEW_FORM                         102
#define          MOVE_FORM                         103
#define          GET_ACTIVESCRID                   104
#define          GET_ACTIVEWIN1ID                  105
#define          GET_ACTIVEWIN2ID                  106
#define          ENABLE_UI                         107
#define          ENABLE_FORM                       108
#define          GET_UIMSG                         109
#define          GET_UISTATUS                      110
#define          GET_FORMSTATUS                    111
#define          GET_OBJPROPERTY                   112
#define          SET_OBJPROPERTY                   113
#define          REDRAW_FORM                       114
#define          REDRAW_OBJECT                     115
#define          GET_UIMSGMAX                      116
#define          GET_UIMSGADV                      117

// Chart Object Commands
#define          CHART_ADDPOINT                    120
#define          CHART_CLEAR                       121
#define          CHART_HCL                         122
#define          CHART_VCL                         123

// TextBox Object Commands
#define          TEXTBOX_CLEAR                     124
#define          TEXTBOX_STATE                     125
#define          TEXTBOX_TEXT                      126
#define          TEXTBOX_NUMBER                    127

// BarGraph Object Commands
#define          BARGRAPH_VALUE                    128

// Button Object Commands
#define          BUTTON_STATE                      129

// NumberBox Object Commands
#define          NUMBERBOX_VALUE                   130

// Needle Object Commands
#define          NEEDLE_VALUE                      131

// Slider Object Commands
#define          SLIDER_VALUE                      132

// PictureBox Object Commands
#define          PICTUREBOX_CLEAR                  140
#define          PICTUREBOX_BITMAP                 141
#define          PICTUREBOX_LINE                   142
#define          PICTUREBOX_RECTANGLE              143
#define          PICTUREBOX_CIRCLE                 144
#define          PICTUREBOX_SETPIXEL               145
#define          PICTUREBOX_GETPIXEL               146
#define          PICTUREBOX_COPYAREA               147
#define          PICTUREBOX_PASTEAREA              148
#define          PICTUREBOX_PRINT                  149
#define          PICTUREBOX_PICTURE                150

// ImageSeq and Animation Object Commands
#define          ANIMATION_PLAY                    160
#define          ANIMATION_STOP                    161
#define          IMAGE_VALUE                       162

/********************************************************************************
* SegeNT GUI Commands RXNOB and TXNOB
* TXNOB: It is the command Data Field Bytes Count
* RXNOB: It is the command Response Data Field Bytes Count
*********************************************************************************/
#define LOAD_FORM_TXNOB                            2

#define DRAW_FORM_TXNOB                            2

#define VIEW_FORM_TXNOB                            3

#define MOVE_FORM_TXNOB                            6

#define GET_ACTIVESCRID_TXNOB                      1
#define GET_ACTIVESCRID_RXNOB                      1

#define GET_ACTIVEWIN1ID_TXNOB                     1
#define GET_ACTIVEWIN1ID_RXNOB                     1

#define GET_ACTIVEWIN2ID_TXNOB                     1
#define GET_ACTIVEWIN2ID_RXNOB                     1

#define ENABLE_UI_TXNOB                            2

#define ENABLE_FORM_TXNOB                          3

#define GET_UIMSG_TXNOB                            1
#define GET_UIMSG_RXNOB                            6

#define GET_UISTATUS_TXNOB                         1
#define GET_UISTATUS_RXNOB                         1

#define GET_FORMSTATUS_TXNOB                       2
#define GET_FORMSTATUS_RXNOB                       1

#define GET_OBJPROPERTY_TXNOB                      4
#define GET_OBJPROPERTY_RXNOB                      4

#define SET_OBJPROPERTY_TXNOB                      5

#define REDRAW_FORM_TXNOB                          2

#define REDRAW_OBJECT_TXNOB                        3

#define GET_UIMSGMAX_TXNOB                         1
#define GET_UIMSGMAX_RXNOB                         11

#define GET_UIMSGADV_TXNOB                         1
#define GET_UIMSGADV_RXNOB                         13


#define CHART_ADDPOINT_TXNOB                       18

#define CHART_CLEAR_TXNOB                          2

#define CHART_HCL_TXNOB                            6

#define CHART_VCL_TXNOB                            6


#define TEXTBOX_CLEAR_TXNOB                        2

#define TEXTBOX_STATE_TXNOB                        3

#define TEXTBOX_TEXT_TXNOB                         2

#define TEXTBOX_NUMBER_TXNOB                       8


#define BARGRAPH_VALUE_TXNOB                       5


#define BUTTON_STATE_TXNOB                         3


#define NUMBERBOX_VALUE_TXNOB                      6


#define NEEDLE_VALUE_TXNOB                         4


#define SLIDER_VALUE_TXNOB                         4


#define PICTUREBOX_CLEAR_TXNOB                     2

#define PICTUREBOX_BITMAP_TXNOB                    10

#define PICTUREBOX_LINE_TXNOB                      10

#define PICTUREBOX_RECTANGLE_TXNOB                 12

#define PICTUREBOX_CIRCLE_TXNOB                    9

#define PICTUREBOX_SETPIXEL_TXNOB                  6

#define PICTUREBOX_GETPIXEL_TXNOB                  6
#define PICTUREBOX_GETPIXEL_RXNOB                  2

#define PICTUREBOX_COPYAREA_TXNOB                  8

#define PICTUREBOX_PASTEAREA_TXNOB                 8

#define PICTUREBOX_PRINT_TXNOB                     6

#define PICTUREBOX_PICTURE_TXNOB                   268


#define ANIMATION_PLAY_TXNOB                       2

#define ANIMATION_STOP_TXNOB                       2

#define IMAGE_VALUE_TXNOB                          3

/****************************************************************************************************************/
// Functions

void GuiCmd_Load_Form(BYTE ID);

void GuiCmd_Draw_Form(BYTE ID);

void GuiCmd_View_Form(BYTE ID, BYTE Value);

void GuiCmd_Move_Form(BYTE ID, WORD X, WORD Y);

BYTE GuiCmd_Get_ActiveScrID();

BYTE GuiCmd_Get_ActiveWin1ID();

BYTE GuiCmd_Get_ActiveWin2ID();

void GuiCmd_Enable_UI(BYTE Value);

void GuiCmd_Enable_Form(BYTE ID, BYTE Value);

void GuiCmd_Get_UIMsg();

void GuiCmd_Get_UIMsgAdv();

BYTE GuiCmd_Get_UIStatus();

BYTE GuiCmd_Get_FormStatus(BYTE ID);

BYTE GuiCmd_Get_ObjProperty_Byte(BYTE Code, BYTE ID, BYTE ProIndex);

WORD GuiCmd_Get_ObjProperty_Word(BYTE Code, BYTE ID, BYTE ProIndex);

DWORD GuiCmd_Get_ObjProperty_DWord(BYTE Code, BYTE ID, BYTE ProIndex);

void GuiCmd_Set_ObjProperty_Byte(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, BYTE Value);

void GuiCmd_Set_ObjProperty_Word(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, WORD Value);

void GuiCmd_Set_ObjProperty_DWord(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, DWORD Value);

void GuiCmd_Set_ObjProperty_String(BYTE Code, BYTE ID, BYTE ProIndex, BYTE Mode, BYTE* pText);

void GuiCmd_Redraw_Form(BYTE ID);

void GuiCmd_Redraw_Object(BYTE Code, BYTE ID);

void GuiCmd_Chart_AddPoint(BYTE ID, WORD X0, WORD Y0, WORD X1, WORD Y1, WORD X2, WORD Y2, WORD X3, WORD Y3);

void GuiCmd_Chart_Clear(BYTE ID);

void GuiCmd_Chart_HCL(BYTE ID, WORD Y, WORD Color);

void GuiCmd_Chart_VCL(BYTE ID, WORD X, WORD Color);

void GuiCmd_TextBox_Clear(BYTE ID);

void GuiCmd_TextBox_State(BYTE ID, BYTE Value);

void GuiCmd_TextBox_Text(BYTE ID, BYTE* pText);

void GuiCmd_TextBox_Number(BYTE ID, BYTE LZ, BYTE DP, DWORD Value);

void GuiCmd_BarGraph_Value(BYTE ID, WORD Value, BYTE BitmapIndex);

void GuiCmd_Button_State(BYTE ID, BYTE Value);

void GuiCmd_NumberBox_Value(BYTE ID, DWORD Value);

void GuiCmd_Needle_Value(BYTE ID, WORD Value);

void GuiCmd_Slider_Value(BYTE ID, WORD Value);

void GuiCmd_PictureBox_Clear(BYTE ID);

void GuiCmd_PictureBox_Bitmap(BYTE ID, WORD BitmapID, BYTE Rot, BYTE Mir, WORD X, WORD Y);

void GuiCmd_PictureBox_Line(BYTE ID, WORD X1, WORD Y1, WORD X2, WORD Y2);

void GuiCmd_PictureBox_Rectangle(BYTE ID, WORD X1, WORD Y1, WORD X2, WORD Y2, BYTE Round, BYTE Filled);

void GuiCmd_PictureBox_Circle(BYTE ID, WORD X0, WORD Y0, WORD Rad, BYTE Filled);

void GuiCmd_PictureBox_SetPixel(BYTE ID, WORD X0, WORD Y0);

WORD GuiCmd_PictureBox_GetPixel(BYTE ID, WORD X0, WORD Y0);

void GuiCmd_PictureBox_CopyArea(BYTE ID, WORD X, WORD Y, BYTE W, BYTE H);

void GuiCmd_PictureBox_PasteArea(BYTE ID, WORD X, WORD Y, BYTE W, BYTE H);

void GuiCmd_PictureBox_Print(BYTE ID, WORD CurX, WORD CurY, BYTE* pText);

void GuiCmd_PictureBox_PrintChar(BYTE ID, WORD CurX, WORD CurY, BYTE Char);

void GuiCmd_PictureBox_Picture(BYTE ID, WORD X, WORD Y, WORD W, WORD H, WORD Block);

void GuiCmd_Animation_Play(BYTE ID);

void GuiCmd_Animation_Stop(BYTE ID);

void GuiCmd_Image_Value(BYTE ID, BYTE Value);

