/*********************************************************************
 *
 *	Hardware specific definitions For EVL-CA32 board
 *  
 *********************************************************************
 * FileName:        HardwareProfile.h
 * Dependencies:    None
 * Processor:       PIC32MX
 * Compiler:        Microchip C32 v1.00 or higher
 *					Microchip C30 v3.01 or higher
 * Company:         Haidar Technology
 *
 *
 * Author               Date		Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
 ********************************************************************/


/*********************************************************************
* GetSystemClock() returns system clock frequency.
*
* GetPeripheralClock() returns peripheral clock frequency.
*
* GetInstructionClock() returns instruction clock frequency.
*
********************************************************************/

#define	GetSystemClock()            (80000000ul)         // 10 MHz/2 x 16 PLL
#define	GetPeripheralClock()		(GetSystemClock()/(1<<OSCCONbits.PBDIV)) // 80MHZ
#define	GetInstructionClock()		(GetSystemClock()/PFMWSbits.CHECON)

#define BOARD_VERSION_CODE          0xAAAA
#define BOARD_VERSION               "1.0"
#define BOARD_NAME                  "EVL-CA32"
#define BOARD_FIRMWARE_VERSION      "1.0"          

/*********************************************************************
* Control Pins FOR LEDs
*********************************************************************/

// LED1
#define LED1_LAT_BIT          LATGbits.LATG13
#define LED1_TRIS_BIT         TRISGbits.TRISG13

// LED2
#define LED2_LAT_BIT          LATEbits.LATE2
#define LED2_TRIS_BIT         TRISEbits.TRISE2

// LED3
#define LED3_LAT_BIT          LATEbits.LATE3
#define LED3_TRIS_BIT         TRISEbits.TRISE3

// LED4
#define LED4_LAT_BIT          LATEbits.LATE4
#define LED4_TRIS_BIT         TRISEbits.TRISE4


/*********************************************************************
* Control Pins For The Display Module or the Embedded GUI Board
*********************************************************************/

// NotifyHost (Input) connected to INT3 
#define NotifyHost              PORTAbits.RA14
#define NotifyHost_TRIS_BIT     TRISAbits.TRISA14

// Ready (Input)
#define Ready                   PORTDbits.RD8
#define Ready_TRIS_BIT          TRISDbits.TRISD8

/*********************************************************************
* Control Pins for Switches
**********************************************************************/

// Switch 1 or F1 (Input) connected to CN8
#define F1                  PORTGbits.RG6
#define SW1_TRIS_BIT        TRISGbits.TRISG6

// Switch 2 (Input) or F2 connected to CN9
#define F2                  PORTGbits.RG7
#define SW2_TRIS_BIT        TRISGbits.TRISG7

/*********************************************************************
* Control Pins for the Optional Optical Encoder
**********************************************************************/

// Encoder switch (Input) connected to INT4
#define ENC_Switch_LAT_BIT              LATAbits.LATA15
#define ENC_Switch_TRIS_BIT             TRISAbits.TRISA15

// Encoder Phase A (Input) connected to INT2
#define ENC_PhaseA_LAT_BIT              LATEbits.LATE9
#define ENC_PhaseA_TRIS_BIT             TRISEbits.TRISE9

// Encoder Phase B (Input) connected to INT1
#define ENC_PhaseB_LAT_BIT              LATEbits.LATE8
#define ENC_PhaseB_TRIS_BIT             TRISEbits.TRISE8

/*********************************************************************
* Control Pins (PWM) for the RGB LED
**********************************************************************/

// OC2 for Blue LED  
#define PWM_Blue_LAT_BIT                LATDbits.LATD1
#define PWM_Blue_TRIS_BIT               TRISDbits.TRISD1

// OC3 for Red LED (OC2) 
#define PWM_Red_LAT_BIT                 LATDbits.LATD2
#define PWM_Red_TRIS_BIT                TRISDbits.TRISD2

// OC4 for Green LED 
#define PWM_Green_LAT_BIT                LATDbits.LATD3
#define PWM_Green_TRIS_BIT               TRISDbits.TRISD3


/*********************************************************************
* Control Pins for the 4 analog inputs ADC
*********************************************************************/

// CH0 (AN5)
#define CH0_LAT_BIT             LATBbits.LATB5
#define CH0_TRIS_BIT            TRISBbits.TRISB5

// CH1 (AN4)
#define CH1_LAT_BIT             LATBbits.LATB4
#define CH1_TRIS_BIT            TRISBbits.TRISB4

// CH2 (AN4)
#define CH2_LAT_BIT             LATBbits.LATB3
#define CH2_TRIS_BIT            TRISBbits.TRISB3

// CH3 (AN2) Connected to on board POT
#define CH3_LAT_BIT             LATBbits.LATB2
#define CH3_TRIS_BIT            TRISBbits.TRISB2


/*********************************************************************
* UART1 is used for the LCD
**********************************************************************/

// Definitions for RX pin
#define U1RX                LATFbits.LATF2
#define RX_TRIS_BIT         TRISFbits.TRISF2

// Definitions for TX pin
#define U1TX                LATFbits.LATF3
#define TX_TRIS_BIT         TRISFbits.TRISF3


/*********************************************************************
* UART2 is AUX
**********************************************************************/

// Definitions for RX pin
#define U2RX                LATFbits.LATF4
#define RX2_TRIS_BIT         TRISFbits.TRISF4

// Definitions for TX pin
#define U2TX                LATFbits.LATF5
#define TX2_TRIS_BIT         TRISFbits.TRISF5
