/*****************************************************************************
 * General Housekeeping driver for SegeNT
 *****************************************************************************
 * FileName:        HouseKeeping.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar		    4/17/2014	...
 *****************************************************************************/

#include "MainDemo.h"
#include "RS232.h"
#include "HouseKeeping.h"
#include "LED.h"
#include "ADC.h"
#include "PWM.h"

#include "Demo_VGA_CA32.h"
#include "UiHandler.h"

#include "Screen_Chart.h"
#include "Screen_Control.h"
#include "Screen_DashBoard.h"
#include "Screen_Thermostate.h"
#include "Screen_Tools.h"


/********************************************************************/
#define __T2_ISR    __ISR(_TIMER_2_VECTOR, ipl4)

void __T2_ISR _T2Interrupt(void)
{

  mT2ClearIntFlag();              // Clear T2 interrupt flag

  HKTimer_1++;                      // increment HouseKeeping HKTimer_1
  HKTimer_2++;                      // increment HouseKeeping HKTimer_2
  ChartTimer++; 
  ControlTimer++;
  DashBoardTimer++;
  Thermostate_Timer++;
  Tools_Timer++;
   
   if (HKTimer_1 == 100)
    {                                       // Do every 100 msec
      HKTimer_1 = 0;
      LED1Toggle();                       // Toggle HB LED
    }

// Chart Update
   if (ChartTimer >= ChartUpdateTime)
    {
      ChartTimer = 0;
      ChartUpdateFlag = 0;
      if ((ActScrID == SCREEN_CHART)&&(ChartUpdateEnable == 1))
       {
         ChartUpdateFlag = 1;
       }
    }

// Control Update
   if (ControlTimer >= ControlUpdateTime)
    {
      ControlTimer = 0;
      ControlUpdateFlag = 0;
      if ((ActScrID == SCREEN_CONTROL)&&(ControlUpdateEnable == 1))
       {
         ControlUpdateFlag = 1;
       }
    }

// DashBoard Update
   if (DashBoardTimer >= DashBoardUpdateTime)
    {
      DashBoardTimer = 0;
      DashBoardUpdateFlag = 0;
      if ((ActScrID == SCREEN_DASHBOARD)&&(DashBoardUpdateEnable == 1))
       {
         DashBoardUpdateFlag = 1;
       }
    }  

 // Thermostate Update
   if (Thermostate_Timer >= Thermostate_UpdateTime)
    {
      Thermostate_Timer = 0;
      Thermostate_UpdateFlag = 0;
      if ((ActScrID == SCREEN_THERMOSTATE)&&(Thermostate_UpdateEnable == 1))
       {
         Thermostate_UpdateFlag = 1;
       }
    }

  // Tools Update
   if (Tools_Timer >= Tools_UpdateTime)
    {
      Tools_Timer = 0;
      Tools_UpdateFlag = 0;
      if ((ActScrID == SCREEN_TOOLS)&&(Tools_UpdateEnable == 1))
       {
         Tools_UpdateFlag = 1;
       }
    }    
        
}

/********************************************************************/
void HouseKeepingInit(void)
{
// Clear HK Timers
   HKTimer_1 = 0;
   HKTimer_2 = 0;
// Intialize Timer 5 for 1msec interrupt
   OpenTimer2(T2_ON | T2_PS_1_256,HKTIMEBASE );
   ConfigIntTimer2(T2_INT_ON | T2_INT_PRIOR_4);
}


