/*****************************************************************************
 * Main Driver for SegeNT                          
 *****************************************************************************
 * FileName:        MainDemo.c
 * Dependencies:    MainDemo.h
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * AH                   5/27/09 
 *****************************************************************************/

#include "MainDemo.h"
#include "RS232.h"
#include "HouseKeeping.h"
#include "LED.h"
#include "PWM.h"
#include "ADC.h"
#include "LED.h"
#include "TerCommands.h"
#include "GUICommands.h"

#include "Demo_VGA_CA32.h"
#include "UiHandler.h"

#include "Screen_Chart.h"
#include "Screen_Control.h"
#include "Screen_DashBoard.h"
#include "Screen_Thermostate.h"
#include "Screen_Tools.h"

// Configuration bits
// External Clock 10 MHZ EC. 10/2 * 16 = 80MHZ
#pragma config FPLLODIV = DIV_1, FPLLMUL = MUL_16, FPLLIDIV = DIV_2, FWDTEN = OFF, FCKSM = CSECME, FPBDIV = DIV_1
#pragma config OSCIOFNC = ON, POSCMOD = EC, FSOSCEN = OFF, FNOSC = PRIPLL
#pragma config CP = OFF, BWP = OFF, PWP = OFF
#pragma config ICESEL = ICS_PGx1

// Set DEBUG To ON if you are going to use ICD
#pragma config DEBUG = OFF

/**********************************************************************************************/

int main(void)
{
 int CH0;
 int CH1;
 int CH2;
 int CH3;

 int CH0_New;
 int CH1_New;
 int CH2_New;
 int CH3_New;

 int CH0_Old;
 int CH1_Old;
 int CH2_Old;
 int CH3_Old;

 DWORD CH0_Voltage;

 BYTE Temp;

 DWORD AN_Voltage;

// Initilaize Hardware pins
HardwareInit();

// Initialize HouseKeepint Interrupt Loop
HouseKeepingInit();

// Init ADC
ADCInit();

// Init PWMs
initPWM_Red();
initPWM_Green();
initPWM_Blue();

// Initialize Controller 
INTEnableSystemMultiVectoredInt();
SYSTEMConfigPerformance(GetSystemClock());

SetRedPWM(0);
SetBluePWM(0);
SetGreenPWM(0);

DelayMs(200);

// Wait for the Display Module or the Embedded board to be ready
IsSegeReady();

// Initialize UART
UARTInit();

// Initialize ui Interrupt
uiInit();

// Show the Splash Screen
Show_Screen_Splash();

// Delay for 5 sec
DelayMs(5000);

// Show the Main Screen
Show_Screen_Main();

Temp = 0;

while (1)
 {
   uiService(); 

    // Chart Screen Update
     if ((ActScrID == SCREEN_CHART)&&(ChartUpdateEnable == 1)&&(ChartUpdateFlag == 1))
       {
         CH0 = (ADC_Array[0]/16) + 304;
         CH1 = (ADC_Array[1]/16) + 212;
         CH2 = (ADC_Array[2]/16) + 120;
         CH3 = (ADC_Array[3]/16) + 28;
         
         // Enable or Disable Chart CH
         if (CH_Enable[0] == 0)
          {
            CH0 = 0;
            CH0_Old = 0;
          }
         if (CH_Enable[1] == 0)
          {
            CH1 = 0;
            CH1_Old = 0;
          }
         if (CH_Enable[2] == 0)
          {
            CH2 = 0;
            CH2_Old = 0;
          }
         if (CH_Enable[3] == 0)
          {
            CH3 = 0;
            CH3_Old = 0;
          }

         // Invert CH
         if (CH_Invert[0] == 1)
          {
            CH0 = (64 - (ADC_Array[0]/16)) + 304;
          }
         if (CH_Invert[1] == 1)
          {
            CH1 = (64 - (ADC_Array[1]/16)) + 212;
          }
         if (CH_Invert[2] == 1)
          {
            CH2 = (64 - (ADC_Array[2]/16)) + 120;
          }
         if (CH_Invert[3] == 1)
          {
            CH3 = (64 - (ADC_Array[3]/16)) + 28;
          }

         // CH Coupling DC or AC
         CH0_New = (ADC_Array[0]/16);
         CH1_New = (ADC_Array[1]/16);
         CH2_New = (ADC_Array[2]/16);
         CH3_New = (ADC_Array[3]/16);
         if (CH_Couple[0] == 1)
          {
            CH0 = (CH0_New - CH0_Old) + 304 + 32;
          }
         if (CH_Couple[1] == 1)
          {
            CH1 = (CH1_New - CH1_Old) + 212 + 32;
          }
         if (CH_Couple[2] == 1)
          {
            CH2 = (CH2_New - CH2_Old) + 120 + 32;
          }
         if (CH_Couple[3] == 1)
          {
            CH3 = (CH3_New - CH3_Old) + 28 + 32;
          }
      
         // Update Graph
         GuiCmd_Chart_AddPoint(SCREEN_CHART_GRAPH_YT,0,CH0,0,CH1,0,CH2,0,CH3);

         // Clear Flag
         ChartUpdateFlag = 0;

         // Update Previous CH values
         CH0_Old = CH0_New;
         CH1_Old = CH1_New;
         CH2_Old = CH2_New;
         CH3_Old = CH3_New;
       }

    // Control Screen Update
    if ((ActScrID == SCREEN_CONTROL)&&(ControlUpdateEnable == 1)&&(ControlUpdateFlag == 1))
       {
         CH0_Voltage = (3300*ADC_Array[0])>>10;
         
         // Update Control Screen NumberBox
         GuiCmd_NumberBox_Value(SCREEN_CONTROL_NUMBERBOX_ANALOG, CH0_Voltage);

         // Update Control Screen BarGraph Red
         GuiCmd_BarGraph_Value(SCREEN_CONTROL_BARGRAPH_RED, ADC_Array[0]>>7, 1);

         // Update Control Screen BarGraph Green
         GuiCmd_BarGraph_Value(SCREEN_CONTROL_BARGRAPH_GREEN, ADC_Array[0]>>6, 1);

         // Update Control Screen BarGraph Yellow
         GuiCmd_BarGraph_Value(SCREEN_CONTROL_BARGRAPH_YELLOW, ADC_Array[0]>>5, 1);
         
         // Update Control Screen WaterFlow TextBox
         GuiCmd_TextBox_Number(SCREEN_CONTROL_TEXTBOX_WATERFLOW, 1 , 0, ADC_Array[0]);

         // Update Control Screen Tank Full TextBox
         GuiCmd_TextBox_Number(SCREEN_CONTROL_TEXTBOX_TANKFULL, 1 , 0, (100*ADC_Array[0])>>10);

         // Update Control Screen Pressure TextBox
         GuiCmd_TextBox_Number(SCREEN_CONTROL_TEXTBOX_PRESSURE, 1 , 0, ADC_Array[0]>>4);

         // Update Control Screen Tank1 BarGraph
         GuiCmd_BarGraph_Value(SCREEN_CONTROL_BARGRAPH_TANK1, (75*ADC_Array[0])>>10, 1);

         // Update Control Screen Tank2 BarGraph
         GuiCmd_BarGraph_Value(SCREEN_CONTROL_BARGRAPH_TANK2, (75*ADC_Array[0])>>10, 1);

         // Update Control Screen WaterFlow ImageSeq
         GuiCmd_Image_Value(SCREEN_CONTROL_ANIMATION_WATERFLOW, Temp);

         Temp++;

         if (Temp > 5)
          {
            Temp = 0;
          }

         // Clear Flag
         ControlUpdateFlag = 0;
       }

    // DashBoard Update
    if ((ActScrID == SCREEN_DASHBOARD)&&(DashBoardUpdateEnable == 1)&&(DashBoardUpdateFlag == 1))
       {
         // Update Speed Guage
         GuiCmd_Needle_Value(SCREEN_DASHBOARD_NEEDLE_SPEED, ((DWORD)100*ADC_Array[0])/341);

         // Update RPM Guage
         GuiCmd_Needle_Value(SCREEN_DASHBOARD_NEEDLE_RPM, ((DWORD)100*ADC_Array[0])/341);

         // Update Temp Guage
         GuiCmd_Needle_Value(SCREEN_DASHBOARD_NEEDLE_TEMP, ADC_Array[0]/11);

         // Update Oil Pressure Guage
         GuiCmd_Needle_Value(SCREEN_DASHBOARD_NEEDLE_OILPRESSURE, ADC_Array[0]/4);

         // Update Turbo Pressure Guage
         GuiCmd_Needle_Value(SCREEN_DASHBOARD_NEEDLE_TURBOPRESSURE, ADC_Array[0]/4);

         // Update Fuel Guage
         GuiCmd_Needle_Value(SCREEN_DASHBOARD_NEEDLE_FUEL, ADC_Array[0]/11);

         // Update Speed TextBox
         GuiCmd_TextBox_Number(SCREEN_DASHBOARD_TEXTBOX_SPEED, 1 , 0, ADC_Array[0]/3);

         // Update RPM TextBox
         GuiCmd_TextBox_Number(SCREEN_DASHBOARD_TEXTBOX_RPM, 1 , 0, ((DWORD)1000*(ADC_Array[0])/113));

         // Update Speed BarGraph
         GuiCmd_BarGraph_Value(SCREEN_DASHBOARD_BARGRAPH_SPEED, ADC_Array[0]/5, 1);

         // Update RPM BarGraph
         GuiCmd_BarGraph_Value(SCREEN_DASHBOARD_BARGRAPH_RPM, ADC_Array[0]/5, 1);

         // Update Fuel ImageSeq
         if (ADC_Array[0]/11 < 10)
          {
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_FUEL, 1);
          }
         else
          {
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_FUEL, 0);
          }

         // Update Temp ImageSeq
         if (ADC_Array[0]/11 > 65)
          {
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_TEMP, 1);
          }
         else
          {
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_TEMP, 0);
          }

          // Update Engine and Battery ImageSeq
         if (ADC_Array[0]/3 > 270)
          {
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_ENGINE, 1);
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_BATTERY, 1);
          }
         else
          {
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_ENGINE, 0);
            GuiCmd_Image_Value(SCREEN_DASHBOARD_IMAGE_BATTERY, 0);
          }

         // Clear Flag
         DashBoardUpdateFlag = 0;
       }

    // Thermostate Update
    if ((ActScrID == SCREEN_THERMOSTATE)&&(Thermostate_UpdateEnable == 1)&&(Thermostate_UpdateFlag == 1))
       {
         // Update Indoor Temp
         GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_INDOORTEMP, ((100*ADC_Array[0])>>11) + 40);

         // Update Indoor Humidity
         GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_INDOORHUMIDITY, ((100*ADC_Array[0])>>11) + 20);

         // Update OutDoor Temp
         GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_OUTDOORTEMP, (100*ADC_Array[0])>>10);

         // Update OutDoor Humidity
         GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_OUTDOORHUMIDITY, ((100*ADC_Array[0])>>11) + 30);

         // Update Weather Status
         GuiCmd_Image_Value(SCREEN_THERMOSTATE_IMAGE_WEATHERSTATUS, ADC_Array[0]/204);

         // Clear Flag
         Thermostate_UpdateFlag = 0;
       }

   // Tools Update
    if ((ActScrID == SCREEN_TOOLS)&&(Tools_UpdateEnable == 1)&&(Tools_UpdateFlag == 1))
       {
         if (Tools_CH0 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(0);
            AN_Voltage = (3300*AnalogInput[0])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH0, 1 , 3, AN_Voltage);
          }

        if (Tools_CH1 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(1);
            AN_Voltage = (3300*AnalogInput[1])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH1, 1 , 3, AN_Voltage);
          }

       if (Tools_CH2 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(2);
            AN_Voltage = (3300*AnalogInput[2])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH2, 1 , 3, AN_Voltage);
          }

        if (Tools_CH3 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(3);
            AN_Voltage = (3300*AnalogInput[3])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH3, 1 , 3, AN_Voltage);
          }

        if (Tools_CH4 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(4);
            AN_Voltage = (3300*AnalogInput[4])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH4, 1 , 3, AN_Voltage);
          }

        if (Tools_CH5 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(5);
            AN_Voltage = (3300*AnalogInput[5])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH5, 1 , 3, AN_Voltage);
          }

        if (Tools_CH6 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(6);
            AN_Voltage = (3300*AnalogInput[6])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH6, 1 , 3, AN_Voltage);
          }

        if (Tools_CH7 == 1)
          {
            // Get Analog input
            TerCmd_Get_AnalogInput(7);
            AN_Voltage = (3300*AnalogInput[7])>>10;
            // Update Text Box
            GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_CH7, 1 , 3, AN_Voltage);
          }

        // Clear Update Flag
        Tools_UpdateFlag = 0;
     }
 }   
}


/********************************************************************/
void  DelayMs(WORD time)
{
    while(time--)
    {
        unsigned int int_status;

        int_status = INTDisableInterrupts();
        OpenCoreTimer(GetSystemClock() / 2000);     // core timer is at 1/2 system clock
        INTRestoreInterrupts(int_status);

        mCTClearIntFlag();

        while(!mCTGetIntFlag());

    }

    mCTClearIntFlag();
}
/********************************************************************/
void HardwareInit()
{
 // ADC Channels
 DDPCON = 0;                                // Disable JTAG port
 AD1PCFGSET = 0xffff;                      // All Digital
 AD1PCFGCLR = 0x003C;                       // AN2, AN3, AN4 and AN5 are enabled
 CM1CONCLR = 0xffff;
 CM2CONCLR = 0xffff;
 
 // On board LEDs                         
 LED1_TRIS_BIT = 0;
 LED2_TRIS_BIT = 0;   
 LED3_TRIS_BIT = 0;
 LED4_TRIS_BIT = 0;
 LED1OFF();
 LED2OFF();
 LED3OFF();
 LED4OFF();

 // Display Module Control
 NotifyHost_TRIS_BIT = 1;
 Ready_TRIS_BIT = 1;
 RX_TRIS_BIT = 1;
 TX_TRIS_BIT = 0;
 
 // On board switches
 SW1_TRIS_BIT = 1;
 SW2_TRIS_BIT = 1;

 // Optional Encoder
 ENC_Switch_TRIS_BIT = 1;
 ENC_PhaseA_TRIS_BIT = 1;
 ENC_PhaseB_TRIS_BIT = 1;

 // RGB PWM outputs
 PWM_Blue_TRIS_BIT = 0;
 PWM_Red_TRIS_BIT = 0;
 PWM_Green_TRIS_BIT = 0;
 PWM_Blue_LAT_BIT = 0;
 PWM_Red_LAT_BIT = 0;
 PWM_Green_LAT_BIT = 0;

 // AUX UART2
 RX2_TRIS_BIT = 1;
 TX2_TRIS_BIT = 0;
}
/*****************************************************************************/

    