/*****************************************************************************
 * Simple UART driver for SegeNT
 *****************************************************************************
 * FileName:        RS232.c
 * Dependencies:    MainDemo.h
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  Abdul Haidar          4/15/2014 
 *****************************************************************************/

#include "RS232.h"
#include "LED.h"

/****************************************************************************/
// Command Time Out
#define __T4_ISR    __ISR(_TIMER_4_VECTOR, ipl5)

void __T4_ISR _T4Interrupt(void)
{
  mT4ClearIntFlag();                // Clear T4 interrupt flag

  TimeOutCounter++;
  if (TimeOutCounter >= CmdTimeOut)
   {
    Stop_TimeOut();
    TimeOutCounter = 0;
    RXIndex = 0;                    // Clear RX Index Register
    RS232Status.RXDONE = 1;                  // Set RX Done Flag
    CmdStatus = TOE;                 // Set Cmd Status to TimeOut Error
   }
  else
   {
     // Turn off timer 4
     OpenTimer4(T4_OFF | T4_PS_1_256, TO_200);
     // clear Timer4 register
     TMR4 = 0;
     // Turn On timer 4
     OpenTimer4(T4_ON | T4_PS_1_256, TO_200);
   } 
}

/************************************************************************************/
#define __UART1_ISR    __ISR(_UART_1_VECTOR , ipl7)

void __UART1_ISR _UART1Interrupt(void)
{
  if (mU1RXGetIntFlag())
  {
    mU1RXClearIntFlag();           // Clear U1RX flag
    Get_CmdResponse();                    
  } 

  if (mU1EGetIntFlag())
   {
     mU1EClearIntFlag();           // Clear UART1 error flag
     if (U1STAbits.OERR == 1)
      {
        U1STAbits.OERR = 0;       // Clear Overflow error if is set
      }
    } 
}

/***********************************************************************************/
void UARTInit()
{
// Clear Command Status 
   CmdStatus = 0;

   // Clear RS232 Status Register
   RS232Status.Byte = 0;
  
// UART1 Pins
   RX_TRIS_BIT = 1;
   TX_TRIS_BIT = 0;
 
// Intialize Timer 4 as RS232 time out timer.
   ConfigIntTimer4(T4_INT_OFF | T4_INT_PRIOR_5);
         
// Intialize UART1 for 8-bit, one start bit, one stop bit
   U1MODE = 0;
   U1STA = 0;
   U1MODEbits.BRGH = 1;
   U1STAbits.OERR = 0;
   U1MODEbits.UARTEN = 1;    // Turn ON UART1
   U1STAbits.UTXEN = 1;      // Tx is ON
   U1STAbits.URXEN = 1;      // Rx is ON

// 9.6 KB/Sec
  //U1BRG = BRG_9600 ;
  //OpenTimer4(T4_OFF | T4_PS_1_256, TO_200); 
        
// 19.2 KB/Sec
  //U1BRG = BRG_19200 ;
  //OpenTimer4(T4_OFF | T4_PS_1_256, TO_200); 
        
// 38.4 KB/Sec
  //U1BRG = BRG_38400 ;
  //OpenTimer4(T4_OFF | T4_PS_1_256, TO_200); 
        
// 57.6 KB/Sec
  //U1BRG = BRG_57600 ;   
  //OpenTimer4(T4_OFF | T4_PS_1_256, TO_200);
        
// 115.2 KB/Sec
   U1BRG = BRG_115200;
   OpenTimer4(T4_OFF | T4_PS_1_256, TO_200);
        
      
// Intialize UART1 Interrupts
   mU1ClearAllIntFlags();
   SetPriorityIntU1(7);       // UART RX HIGH PROIORITY
   SetSubPriorityIntU1(3);    // Sub Priority High
   DisableIntU1TX;           // Disable TX interrupt
   EnableIntU1RX ;           // Enable RX interrupt
// UART1 Error Interrupt
   mU1EIntEnable(1);        // Enable UART1 Error Interrupt 
}

/**************************************************************************************/
// Recieve the command response bytes
void Get_CmdResponse()
{
 BYTE Temp;

  while (U1STAbits.URXDA == 1)
  {
     Temp = U1RXREG;

     RXIndex++;
     RXBuffer[RXIndex-1] = Temp;
     if (RXIndex == RXCount)
      {
        RS232Status.RXDONE = 1;        // Set RXDoneFlag
        RXIndex = 0;
        Stop_TimeOut();
        CmdStatus = RXBuffer[0];    // Update Command status
      }
  } 
}  

/********************************************************************************/
void Start_TimeOut()
{
  TimeOutCounter = 0;
  RS232Status.Byte = 0;
  RXIndex = 0;
  TMR4 = 0;
  T4CONSET = 0x8000;
  ConfigIntTimer4(T4_INT_ON | T4_INT_PRIOR_5);         
}

/********************************************************************************/
void Stop_TimeOut()
{
  TMR4 = 0;
  T4CONCLR = 0x8000;
  ConfigIntTimer4(T4_INT_OFF | T4_INT_PRIOR_5);    
}

/******************************************************************************/
void Send_Command()
{
  BYTE Temp;

  for ( TXIndex =0; TXIndex < TXCount; TXIndex++)
  {
    while ( U1STAbits.UTXBF);
    U1TXREG = TXBuffer[TXIndex];
  }
   while (!U1STAbits.TRMT);   // Wait untile TRMT is empty

   //Start Time Out Timer
   Start_TimeOut ();
}

/**********************************************************************************/
// Calc Response Checksum
BYTE GetRXChecksum()
{
 BYTE CS;
 WORD i;

 CS =0;
 for ( i = 0; i < (RXCount-1); i++)
  {
     CS = CS + RXBuffer[i];
  }
 return CS;    
}

/**********************************************************************************/
// Calc Command Checksum
BYTE GetTXChecksum()
{
 BYTE CS;
 WORD i;
 
 CS = 0;
 for ( i = 0; i < (TXCount - 1); i++)
  {
    CS = CS + TXBuffer[i];
  }
 return CS;
}
      