/*****************************************************************************
 * Simple UART driver For SegeNT
 *****************************************************************************
 * FileName:        RS232.h
 * Dependencies:    
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar         4/15/2014
 *****************************************************************************/
#include "MainDemo.h"

/******************************************************************************/
// Global Constants

// Command Status Error codes
#define         ACK                       0x06
#define         NAK                       0x15
#define         ERR                       'E'
#define         TOE                       'T'
#define         CSE                       'C'

// SegeNT Default Device ID
#define         SEGE_DEVID            16   // RS232 Communication Address

// Receiver and Transmiiter sizes
#define         SEGE_RXBUFFERSIZE     288
#define         SEGE_TXBUFFERSIZE     288 

// Baud rates constants
#define         BRG_115200        174    //80000000/4/115200 - 1
#define         BRG_57600         346                   
#define         BRG_38400         520
#define         BRG_19200         1041
#define         BRG_9600          2083

// Timer4 Timer value
#define         TO_200            62500               // 200 msec

/**********************************************************************************/
//Global Variables

BYTE RXBuffer[SEGE_RXBUFFERSIZE - 1 ];
BYTE TXBuffer[SEGE_TXBUFFERSIZE - 1];
WORD RXCount;
WORD TXCount;
WORD RXIndex;
WORD TXIndex;
BYTE CmdCode;
BYTE TimeOutCounter;
BYTE CmdStatus;
BYTE CmdInProgress;
BYTE CmdTimeOut;
BYTE RXDoneFlag;

typedef union _RS232STATUS_BYTE
{
  unsigned char Byte;
  struct 
 {
  unsigned char RXDONE:1;         // Recieving the packet has been done
  unsigned char x1:1;          
  unsigned char x2:1;          
  unsigned char x3:1;         
  unsigned char x4:1;          
  unsigned char x5:1;         
  unsigned char x6:1;         
  unsigned char x7:1;         
 };
} RS232STATUS;
volatile RS232STATUS RS232Status;

/**********************************************************************************/
// Macros

#define IsRxDone()           while(!RS232Status.RXDONE);
#define IsSegeReady()        while(Ready);
  
/*********************************************************************************/
//Functions

void UARTInit();

void Get_CmdResponse();

void Start_TimeOut();

void Stop_TimeOut();

void Send_Command();

BYTE GetRXChecksum();

BYTE GetTXChecksum();
