/*****************************************************************************
 * Drawpad Screen driver
 *****************************************************************************
 * FileName:        Screen_Drawpad.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *****************************************************************************/
#include "MainDemo.h"
#include "GUICommands.h"
#include "TerCommands.h"
#include "Demo_VGA_CA32.h"
#include "UiHandler.h"
#include "GUI.h"

#include "Screen_DrawPad.h"
#include "Win1_BitmapBox.h"
#include "Win1_ColorBox.h"
#include "Win1_ShapeBox.h"

#include "LED.h"


/********************************************************************/
void Show_Screen_DrawPad()
{
  ActScrID = SCREEN_DRAWPAD;
  
  // Load Form
  GuiCmd_Load_Form(ActScrID);

  // Set the draw select to draw
  DrawPad_Select = 0; 

  // Get PictureBox Left,Top
  DrawPad_Left = GuiCmd_Get_ObjProperty_Word(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_LEFT);
  DrawPad_Top = GuiCmd_Get_ObjProperty_Word(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_TOP);
  DrawPad_Width = GuiCmd_Get_ObjProperty_Word(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_WIDTH);
  DrawPad_Height = GuiCmd_Get_ObjProperty_Word(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_HEIGHT);

  // Show Screen
  GuiCmd_Draw_Form(ActScrID);
}

/*******************************************************************/
void ui_Screen_DrawPad()
{
 WORD X;
 WORD Y;

 if (UI_Msg.Code == BUTTON_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_DRAWPAD_BUTTON_EXIT:
      Show_Screen_Main();
      break;

      case SCREEN_DRAWPAD_BUTTON_VIDEO:
      Show_Win2_Video();
      break;

      case SCREEN_DRAWPAD_BUTTON_DRAW:
      // Set the draw select to draw
      DrawPad_Select = 0;
      // Enable PictureBox Draw
      GuiCmd_Set_ObjProperty_Byte(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_SKETCHEVENT, REDRAW_NO, 1);
      break;

      case SCREEN_DRAWPAD_BUTTON_PICKCOLOR:
      // Set the draw select to draw Color
      DrawPad_Select = 1;
      Show_Win1_ColorBox();
      break;

      case SCREEN_DRAWPAD_BUTTON_FILL:
      // Set the draw select to Fill Color
      DrawPad_Select = 2;
      Show_Win1_ColorBox();
      break;

      case SCREEN_DRAWPAD_BUTTON_PICTURE:
      // Set the draw select to Draw Bitmap
      DrawPad_Select = 3;
      Show_Win1_BitmapBox();
      break;

      case SCREEN_DRAWPAD_BUTTON_SHAPE:
      // Set the draw select to Draw Shape
      DrawPad_Select = 4;
      Show_Win1_ShapeBox();
      break;

      case SCREEN_DRAWPAD_BUTTON_DELETE:
      GuiCmd_PictureBox_Clear(SCREEN_DRAWPAD_PICTUREBOX_DRAW);
      break;
   }
  }

 if (UI_Msg.Code == PICTUREBOX_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_DRAWPAD_PICTUREBOX_DRAW:
       X = UI_Msg.TX - DrawPad_Left;
       Y = UI_Msg.TY - DrawPad_Top;
       switch (DrawPad_Select)
        {
         case 1:
         // Update PictureBox Draw Color
         GuiCmd_Set_ObjProperty_Word(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_FORECOLOR, REDRAW_NO, ColorBox_Color);
         // Enable PictureBox Draw
         GuiCmd_Set_ObjProperty_Byte(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_SKETCHEVENT, REDRAW_NO, 1);
         break;

         case 2:
         // Update PictureBox Fill Color
         GuiCmd_Set_ObjProperty_Word(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_BACKCOLOR, REDRAW_YES, ColorBox_Color);
         // Enable PictureBox Draw
         GuiCmd_Set_ObjProperty_Byte(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_SKETCHEVENT, REDRAW_NO, 1);
         break;

         case 3:
         // Disable PictureBox Draw
         GuiCmd_Set_ObjProperty_Byte(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_SKETCHEVENT, REDRAW_NO, 0);
         // Show Bitmap
         GuiCmd_PictureBox_Bitmap(SCREEN_DRAWPAD_PICTUREBOX_DRAW, (BITMAPBOX_WORLD + BitmapBox_Index),0,0, X, Y);
         break;

         case 4:
         // Disable PictureBox Draw
         GuiCmd_Set_ObjProperty_Byte(PICTUREBOX_CODE, SCREEN_DRAWPAD_PICTUREBOX_DRAW, PICTUREBOX_PRO_SKETCHEVENT, REDRAW_NO, 0);
         // Draw Shape
         switch (ShapeBox_Shape)
          {
           case SHAPEBOX_SQUARE:
           GuiCmd_PictureBox_Rectangle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, X + 64, Y + 64,0,0);
           break;
           case SHAPEBOX_RECTANGLE:
           GuiCmd_PictureBox_Rectangle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, X + 32, Y + 64,0,0);
           break;
           case SHAPEBOX_BEVEL:
           GuiCmd_PictureBox_Rectangle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, X + 64, Y + 64,1,0);
           break;
           case SHAPEBOX_CIRCLE:
           GuiCmd_PictureBox_Circle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, 32, 0);
           break;
           case SHAPEBOX_FILLEDSQUARE:
           GuiCmd_PictureBox_Rectangle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, X + 64, Y + 64,0,1);
           break;
           case SHAPEBOX_FILLEDRECTANGLE:
           GuiCmd_PictureBox_Rectangle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, X + 32, Y + 64,0,1);
           break;
            case SHAPEBOX_FILLEDBEVEL:
           GuiCmd_PictureBox_Rectangle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, X + 64, Y + 64,1,1);
           break;
           case SHAPEBOX_FILLEDCIRCLE:
           GuiCmd_PictureBox_Circle(SCREEN_DRAWPAD_PICTUREBOX_DRAW, X, Y, 32, 1);
           break;
          }
         break;
      }
  break;
  }
 }
}
 

     


