/*****************************************************************************
 * Keyboard Screen driver
 *****************************************************************************
 * FileName:        Screen_Keyboard.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *****************************************************************************/
#include "MainDemo.h"
#include "GUICommands.h"
#include "TerCommands.h"
#include "Demo_VGA_CA32.h"
#include "UiHandler.h"
#include "GUI.h"

#include "Screen_KeyBoard.h"
#include "Win1_FontBox.h"
#include "Win1_ColorBox.h"

/********************************************************************/
void Show_Screen_KeyBoard()
{
  ActScrID = SCREEN_KEYBOARD;
  
  // Load Form
  GuiCmd_Load_Form(ActScrID);

  KeyBoard_CharCount = 0;
  KeyBoard_CurX = 0;
  KeyBoard_CurY = 0;

  // Get Font0 Height
  TerCmd_Get_FontHeight(0);
  // Get Font0 Characters widths
  TerCmd_Get_FontWidth(0, CharWidth);
  

  // Show Screen
  GuiCmd_Draw_Form(ActScrID);
}

/*******************************************************************/
void ui_Screen_KeyBoard()
{
 if (UI_Msg.Code == BUTTON_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_KEYBOARD_BUTTON_EXIT:
      Show_Screen_Main();
      break;

      case SCREEN_KEYBOARD_BUTTON_FONT:
      Show_Win1_FontBox();
      break;

      case SCREEN_KEYBOARD_BUTTON_COLOR:
      Show_Win1_ColorBox();
      break;

      case SCREEN_KEYBOARD_BUTTON_CAP:
      KeyBoard_Cap = UI_Msg.Value;
      break;

      case SCREEN_KEYBOARD_BUTTON_DELETE:
      GuiCmd_PictureBox_Clear(SCREEN_KEYBOARD_PICTUREBOX_TEXT);
      KeyBoard_CharCount = 0;
      KeyBoard_CurX = 0;
      KeyBoard_CurY = 0;
      break;

      case SCREEN_KEYBOARD_BUTTON_ENTER:
      KeyBoard_Char = 10;
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        KeyBoard_CurX = 0;
        KeyBoard_CurY = KeyBoard_CurY + FontHeight;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_Q:
      KeyBoard_Char = 'q';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'Q';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_W:
      KeyBoard_Char = 'w';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'W';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_E:
      KeyBoard_Char = 'e';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'E';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_R:
      KeyBoard_Char = 'r';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'R';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_T:
      KeyBoard_Char = 't';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'T';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_Y:
      KeyBoard_Char = 'y';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'Y';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_U:
      KeyBoard_Char = 'u';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'U';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_I:
      KeyBoard_Char = 'i';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'I';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_O:
      KeyBoard_Char = 'o';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'O';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_P:
      KeyBoard_Char = 'p';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'P';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_A:
      KeyBoard_Char = 'a';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'A';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_S:
      KeyBoard_Char = 's';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'S';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_D:
      KeyBoard_Char = 'd';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'D';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_F:
      KeyBoard_Char = 'f';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'F';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_G:
      KeyBoard_Char = 'g';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'G';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       } 
      break;

      case SCREEN_KEYBOARD_BUTTON_H:
      KeyBoard_Char = 'h';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'H';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_J:
      KeyBoard_Char = 'j';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'J';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_K:
      KeyBoard_Char = 'k';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'K';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break; 

      case SCREEN_KEYBOARD_BUTTON_L:
      KeyBoard_Char = 'l';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'L';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_Z:
      KeyBoard_Char = 'z';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'Z';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_X:
      KeyBoard_Char = 'x';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'X';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break; 

      case SCREEN_KEYBOARD_BUTTON_C:
      KeyBoard_Char = 'c';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'C';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_V:
      KeyBoard_Char = 'v';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'V';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_B:
      KeyBoard_Char = 'b';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'B';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_N:
      KeyBoard_Char = 'n';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'N';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_M:
      KeyBoard_Char = 'm';
      if (KeyBoard_Cap == 1)
       {
         KeyBoard_Char = 'M';
       }
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_0:
      KeyBoard_Char = '0';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_1:
      KeyBoard_Char = '1';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_2:
      KeyBoard_Char = '2';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_3:
      KeyBoard_Char = '3';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_4:
      KeyBoard_Char = '4';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_5:
      KeyBoard_Char = '5';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_6:
      KeyBoard_Char = '6';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_7:
      KeyBoard_Char = '7';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_8:
      KeyBoard_Char = '8';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_9:
      KeyBoard_Char = '9';
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;

      case SCREEN_KEYBOARD_BUTTON_SPACE:
      KeyBoard_Char = 32;
      KeyBoard_CharCount++;
      if (KeyBoard_CharCount < KEYBOARD_MAXCHARCOUNT)
       {
        GuiCmd_PictureBox_PrintChar(SCREEN_KEYBOARD_PICTUREBOX_TEXT, KeyBoard_CurX, KeyBoard_CurY, KeyBoard_Char);
        KeyBoard_CurX = KeyBoard_CurX + CharWidth[KeyBoard_Char - 32] + 1;
        KeyBoard_Text[KeyBoard_CharCount] = KeyBoard_Char;
       }
      break;  
   }
  }
} 

     


