/*****************************************************************************
 * Thermostate Screen driver
 *****************************************************************************
 * FileName:        Screen_Thermostate.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *****************************************************************************/
#include "MainDemo.h"
#include "GUICommands.h"
#include "TerCommands.h"
#include "Demo_VGA_CA32.h"
#include "UiHandler.h"
#include "GUI.h"

#include "Screen_Thermostate.h"


/********************************************************************/
void Show_Screen_Thermostate()
{
  ActScrID = SCREEN_THERMOSTATE;
  
  // Load Form
  GuiCmd_Load_Form(ActScrID);

  // Initialize
  Thermostate_UpdateTime = 250;
  Thermostate_UpdateFlag = 0;
  Thermostate_UpdateEnable = 0;
  Thermostate_Timer = 0;
  Thermostate_IncHoldCounter = 0;
  Thermostate_DecHoldCounter = 0;

  Thermostate_SetTemp = 70;

  // Show Screen
  GuiCmd_Draw_Form(ActScrID);

  GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_SETTEMP, Thermostate_SetTemp);

  // Enable DashBoard Update
  Thermostate_UpdateEnable = 1;
}

/*******************************************************************/
void ui_Screen_Thermostate()
{
 if (UI_Msg.Code == BUTTON_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_THERMOSTATE_BUTTON_EXIT:
      Thermostate_UpdateEnable = 0;
      Show_Screen_Main();
      break;

      case SCREEN_THERMOSTATE_BUTTON_INC:
      switch (UI_Msg.Type)
       {
        case uiEVENT_PRESS:
        Thermostate_SetTemp = Thermostate_SetTemp + 1;
        if (Thermostate_SetTemp > 99)
         {
         Thermostate_SetTemp = 99;
         }
        GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_SETTEMP, Thermostate_SetTemp);
        break;

        case uiEVENT_MOVE:
        Thermostate_IncHoldCounter++;
        if (Thermostate_IncHoldCounter > THERMOSTATE_MAXHOLDCOUNTER)
         {
          Thermostate_IncHoldCounter = 0;
          Thermostate_SetTemp = Thermostate_SetTemp + 1;
          if (Thermostate_SetTemp > 99)
          {
            Thermostate_SetTemp = 99;
          }
          GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_SETTEMP, Thermostate_SetTemp);
          }
         break;

         case uiEVENT_RELEASE:
         Thermostate_IncHoldCounter = 0;
         break;
       } 
      break;

      case SCREEN_THERMOSTATE_BUTTON_DEC:
      switch (UI_Msg.Type)
       {
        case uiEVENT_PRESS:
        Thermostate_SetTemp = Thermostate_SetTemp - 1;
        if (Thermostate_SetTemp < 45)
         {
         Thermostate_SetTemp = 45;
         }
        GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_SETTEMP, Thermostate_SetTemp);
        break;

        case uiEVENT_MOVE:
        Thermostate_DecHoldCounter++;
        if (Thermostate_DecHoldCounter > THERMOSTATE_MAXHOLDCOUNTER)
         {
          Thermostate_DecHoldCounter = 0;
          Thermostate_SetTemp = Thermostate_SetTemp - 1;
          if (Thermostate_SetTemp < 45)
          {
            Thermostate_SetTemp = 45;
          }
          GuiCmd_NumberBox_Value(SCREEN_THERMOSTATE_NUMBERBOX_SETTEMP, Thermostate_SetTemp);
          }
         break;

         case uiEVENT_RELEASE:
         Thermostate_DecHoldCounter = 0;
         break;
       } 
      break;
   }
  }
} 

     


