/*****************************************************************************
 * Tools Screen driver
 *****************************************************************************
 * FileName:        Screen_Tools.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *****************************************************************************/
#include "MainDemo.h"
#include "GUICommands.h"
#include "TerCommands.h"
#include "Demo_VGA_CA32.h"
#include "UiHandler.h"
#include "GUI.h"

#include "Screen_Tools.h"
#include "Win1_Info.h"

/******************************************************************************/
// Internal Audio Names

const char EAN0[] = "DTMF-0";
const char EAN1[] = "DTMF-1";
const char EAN2[] = "DTMF-2";
const char EAN3[] = "DTMF-3";
const char EAN4[] = "DTMF-4";
const char EAN5[] = "DTMF-5";
const char EAN6[] = "DTMF-6";
const char EAN7[] = "DTMF-7";
const char EAN8[] = "DTMF-8";
const char EAN9[] = "DTMF-9";
const char EAN10[] = "DTMF-STAR";
const char EAN11[] = "DTMF-POUND";
const char EAN12[] = "CLICK-16A";
const char EAN13[] = "CLICK-17A";
const char EAN14[] = "CLICK-1A";
const char EAN15[] = "CLICK-1B";
const char EAN16[] = "CLICK-20A";
const char EAN17[] = "CLICK-4C";
const char EAN18[] = "CLICK-D";
const char EAN19[] = "CLICK-O";
const char EAN20[] = "CLICK-R";
const char EAN21[] = "CLICK-T";
const char EAN22[] = "CLICK-U";
const char EAN23[] = "SWITCH";


/********************************************************************/
void Show_Screen_Tools()
{
  ActScrID = SCREEN_TOOLS;
  
  // Load Form
  GuiCmd_Load_Form(ActScrID);

  Tools_AudioSource = 0;
  Tools_AudioID = 16;
  Tools_AudioIDMin = 16;
  Tools_AudioIDMax = 39;

  Tools_CH0 = 0;
  Tools_CH1 = 0;
  Tools_CH2 = 0;
  Tools_CH3 = 0;
  Tools_CH4 = 0;
  Tools_CH5 = 0;
  Tools_CH6 = 0;
  Tools_CH7 = 0;
  
  Tools_UpdateFlag = 0;
  Tools_UpdateTime = 250;
  Tools_UpdateEnable = 0;
  Tools_Timer = 0;

  // Show Screen
  GuiCmd_Draw_Form(ActScrID);

  // Sliders Value
  GuiCmd_Slider_Value(SCREEN_TOOLS_SLIDER_BRIGHTNESS, 100);
  GuiCmd_Slider_Value(SCREEN_TOOLS_SLIDER_ENTVOLUME, 100);
  GuiCmd_Slider_Value(SCREEN_TOOLS_SLIDER_EXTVOLUME, 100);

  // Disable Button
  GuiCmd_Button_State(SCREEN_TOOLS_BUTTON_ENTAUDIO, 2);
  // Set Button Ext Audio to state 0
  GuiCmd_Button_State(SCREEN_TOOLS_BUTTON_EXTAUDIO, 0);
  // Update Auido ID
  GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_AUDIOID,1,0, Tools_AudioID);
  // Update Audio Name
  GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN0);

}

/*******************************************************************/
void ui_Screen_Tools()
{
 if (UI_Msg.Code == BUTTON_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_TOOLS_BUTTON_EXIT:
      Tools_UpdateEnable = 0;
      Show_Screen_Main();
      break;

      case SCREEN_TOOLS_BUTTON_INFO:
      Show_Win1_Info();
      break;

      case SCREEN_TOOLS_BUTTON_ENTAUDIO:
      Tools_AudioSource = 0;
      Tools_AudioID = 16;
      Tools_AudioIDMin = 16;
      Tools_AudioIDMax = 39;
      // Disable Button
      GuiCmd_Button_State(SCREEN_TOOLS_BUTTON_ENTAUDIO, 2);
      // Set Button Ext Audio to state 0
      GuiCmd_Button_State(SCREEN_TOOLS_BUTTON_EXTAUDIO, 0);
      // Update Auido ID
      GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_AUDIOID,1,0, Tools_AudioID);
      // Update Audio Name
      GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN0);
      break;

      case SCREEN_TOOLS_BUTTON_EXTAUDIO:
      Tools_AudioSource = 1;
      Tools_AudioID = 0;
      Tools_AudioIDMin = 0;
      Tools_AudioIDMax = 7;
      // Disable Button
      GuiCmd_Button_State(SCREEN_TOOLS_BUTTON_EXTAUDIO, 2);
      // Set Button Ent Audio to state 0
      GuiCmd_Button_State(SCREEN_TOOLS_BUTTON_ENTAUDIO, 0);
      // Update Auido ID
      GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_AUDIOID,1,0, Tools_AudioID);
      // Clear Audio Name
      GuiCmd_TextBox_Clear(SCREEN_TOOLS_TEXTBOX_AUDIONAME);
      break;

      case SCREEN_TOOLS_BUTTON_AUDIOIDINC:
      Tools_AudioID++;
      if (Tools_AudioID > Tools_AudioIDMax)
       {
        Tools_AudioID = Tools_AudioIDMax;
       }
      // Update Auido ID
      GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_AUDIOID,1,0, Tools_AudioID);
      if (Tools_AudioSource == 0)
       {
        switch (Tools_AudioID)
         {
          case 16:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN0);
          break;
          case 17:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN1);
          break;
          case 18:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN2);
          break;
          case 19:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN3);
          break;
          case 20:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN4);
          break;
          case 21:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN5);
          break;
          case 22:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN6);
          break;
          case 23:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN7);
          break;
          case 24:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN8);
          break;
          case 25:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN9);
          break;
          case 26:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN10);
          break;
          case 27:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN11);
          break;
          case 28:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN12);
          break;
          case 29:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN13);
          break;
          case 30:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN14);
          break;
          case 31:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN15);
          break;
          case 32:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN16);
          break;
          case 33:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN17);
          break;
          case 34:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN18);
          break;
          case 35:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN19);
          break;
          case 36:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN20);
          break;
          case 37:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN21);
          break;
          case 38:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN22);
          break;
          case 39:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN23);
          break;
        }
       }
      break;

      case SCREEN_TOOLS_BUTTON_AUDIOIDDEC:
      Tools_AudioID--;
      if (Tools_AudioID < Tools_AudioIDMin)
       {
        Tools_AudioID = Tools_AudioIDMin;
       }
      // Update Auido ID
      GuiCmd_TextBox_Number(SCREEN_TOOLS_TEXTBOX_AUDIOID,1,0, Tools_AudioID);
      if (Tools_AudioSource == 0)
       {
        switch (Tools_AudioID)
         {
          case 16:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN0);
          break;
          case 17:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN1);
          break;
          case 18:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN2);
          break;
          case 19:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN3);
          break;
          case 20:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN4);
          break;
          case 21:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN5);
          break;
          case 22:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN6);
          break;
          case 23:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN7);
          break;
          case 24:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN8);
          break;
          case 25:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN9);
          break;
          case 26:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN10);
          break;
          case 27:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN11);
          break;
          case 28:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN12);
          break;
          case 29:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN13);
          break;
          case 30:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN14);
          break;
          case 31:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN15);
          break;
          case 32:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN16);
          break;
          case 33:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN17);
          break;
          case 34:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN18);
          break;
          case 35:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN19);
          break;
          case 36:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN20);
          break;
          case 37:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN21);
          break;
          case 38:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN22);
          break;
          case 39:
          // Update Audio Name
          GuiCmd_TextBox_Text(SCREEN_TOOLS_TEXTBOX_AUDIONAME, (char*)EAN23);
          break;
        }
       }
      break;

      case SCREEN_TOOLS_BUTTON_AUDIOPLAY :
      // Play Audio
      TerCmd_Play_Audio(Tools_AudioID);
      break;

      case SCREEN_TOOLS_BUTTON_AUDIOMUTE:
      if (UI_Msg.Value == 1)
       {
         TerCmd_Mute(0);
       }
      else
       {
         TerCmd_Mute(1);
       }
      break;

      case SCREEN_TOOLS_BUTTON_D0:
      // Set DIO
      TerCmd_Set_DigitalOutput(0, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D1:
      // Set DIO
      TerCmd_Set_DigitalOutput(1, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D2:
      // Set DIO
      TerCmd_Set_DigitalOutput(2, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D3:
      // Set DIO
      TerCmd_Set_DigitalOutput(3, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D4:
      // Set DIO
      TerCmd_Set_DigitalOutput(4, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D5:
      // Set DIO
      TerCmd_Set_DigitalOutput(5, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D6:
      // Set DIO
      TerCmd_Set_DigitalOutput(6, UI_Msg.Value);
      break;

      case SCREEN_TOOLS_BUTTON_D7:
      // Set DIO
      TerCmd_Set_DigitalOutput(7, UI_Msg.Value);
      break;
   }
  }

 if (UI_Msg.Code == SLIDER_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_TOOLS_SLIDER_ENTVOLUME:
      TerCmd_Set_EntVolume(UI_Msg.Value);
      break;

      case SCREEN_TOOLS_SLIDER_EXTVOLUME:
      TerCmd_Set_ExtVolume(UI_Msg.Value);
      break;

      case SCREEN_TOOLS_SLIDER_PWM0:
      TerCmd_Set_PWM(0, 2*UI_Msg.Value);
      break;

      case SCREEN_TOOLS_SLIDER_PWM1:
      TerCmd_Set_PWM(1, 2*UI_Msg.Value);
      break;

      case SCREEN_TOOLS_SLIDER_BRIGHTNESS:
      TerCmd_Set_Brightness((UI_Msg.Value) + 25);
      break;
   }
  }

 if (UI_Msg.Code == TEXTBOX_CODE)
  {
   switch (UI_Msg.ID)
   {
      case SCREEN_TOOLS_TEXTBOX_CH0:
      Tools_CH0 = UI_Msg.Value ;
      break;

      case SCREEN_TOOLS_TEXTBOX_CH1:
      Tools_CH1 = UI_Msg.Value ;
      break; 

      case SCREEN_TOOLS_TEXTBOX_CH2:
      Tools_CH2 = UI_Msg.Value ;
      break; 

      case SCREEN_TOOLS_TEXTBOX_CH3:
      Tools_CH3 = UI_Msg.Value ;
      break; 

      case SCREEN_TOOLS_TEXTBOX_CH4:
      Tools_CH4 = UI_Msg.Value ;
      break; 

      case SCREEN_TOOLS_TEXTBOX_CH5:
      Tools_CH5 = UI_Msg.Value ;
      break; 

      case SCREEN_TOOLS_TEXTBOX_CH6:
      Tools_CH6 = UI_Msg.Value ;
      break; 

      case SCREEN_TOOLS_TEXTBOX_CH7:
      Tools_CH7 = UI_Msg.Value ;
      break;
   }
  Tools_UpdateEnable = Tools_CH0 | Tools_CH1 | Tools_CH2 | Tools_CH3 | Tools_CH4 | Tools_CH5 | Tools_CH6 | Tools_CH7;
 }     
} 

     


