/*****************************************************************************
 * SegeNT Terminal Commands 
 *****************************************************************************
 * FileName:        TerCommands.h
 * Dependencies:    
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 *
 * Author               Date               Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar         7/19/2014          
 *****************************************************************************/
#include "MainDemo.h"

/******************************************************************************/
// Global Variables

char ProductNumber[11];
char FirmwareVersion[6];
char SerialNumber[7];
WORD UserVersion;
WORD UserIDNumber0;
WORD UserIDNumber1;
WORD LCDResX;
WORD LCDResY;
BYTE TouchScreenType;
BYTE FlashSize;
BYTE UserFlashSize;
BYTE SegeStatus;
BYTE ProductCode;
BYTE DigitalInput[8];
WORD AnalogInput[8];
WORD PixelColor;
BYTE ActiveLayer;

WORD BitmapWidth;
WORD BitmapHeight;
BYTE BitmapBackStyle;

WORD TextWidth;
WORD TextHeight;
WORD TextLength;
WORD TextLineCount;
BYTE FontHeight;
BYTE FontColorDepth;
BYTE CurrentFont;

typedef struct {
    BYTE    Status;                // Touch screen status
    WORD    X;                     // X coordinate
    WORD    Y;                     // Y coordinate
    WORD    RFU;                   // Reserved for Future use
} TOUCHDATA;
volatile TOUCHDATA TouchData;

/*****************************************************************************************
* SegeNT Terminal Commands codes
******************************************************************************************/
#define          GET_PRODUCTNUMBER                 1
#define          GET_FIRMWAREVERSION               2
#define          GET_SERIALNUMBER                  3
#define          GET_USERVERSION                   4
#define          GET_USERIDNUMBER0                 5
#define          GET_USERIDNUMBER1                 6
#define          GET_LCDSIZE                       7
#define          GET_TOUCHSCREENTYPE               8
#define          GET_FLASHSIZE                     9
#define          GET_USERFLASHSIZE                 10
#define          GET_SYSTEMSTATUS                  11
#define          CAL_TOUCHSCREEN                   12
#define          SET_BRIGHTNESS                    13
#define          SET_BACKLIGHT                     14
#define          SET_BEEP                          15
#define          SET_LCD                           16
#define          SET_USERFLASH                     17
#define          GET_USERFLASH                     18
#define          ERASE_USERFLASH                   25
#define          SET_DIGITALOUTPUT                 19
#define          GET_DIGITALINPUT                  20
#define          GET_ANALOGINPUT                   21
#define          SET_PWM                           22
#define          GET_TOUCHDATA                     23
#define          GET_PRODUCTCODE                   24

// Audio Commands

#define          PLAY_AUDIO                        26
#define          SET_ENTVOLUME                     27
#define          SET_EXTVOLUME                     28
#define          MUTE                              29

// Graphic Commands

#define          CLEAR_SCREEN                      30
#define          SET_BACKCOLOR                     31
#define          SET_DRAWCOLOR                     32
#define          SET_DRAWWIDTH                     33
#define          SET_DRAWTYPE                      34
#define          DRAW_LINE                         35
#define          DRAW_RECTANGLE                    36
#define          DRAW_FILLEDRECTANGLE              37
#define          DRAW_BEVEL                        38
#define          DRAW_FILLEDBEVEL                  39
#define          DRAW_CIRCLE                       40
#define          DRAW_FILLEDCIRCLE                 41
#define          DRAW_PIXEL                        42
#define          COPY_AREA                         43
#define          PASTE_AREA                        44
#define          GET_PIXEL                         45
#define          SET_ACTIVELAYER                   46
#define          GET_ACTIVELAYER                   47
#define          GET_COPYBUFFER                    48


// Bitmap Commands
#define          DRAW_BITMAP                       50
#define          SHOW_BITMAP                       51
#define          GET_BITMAPDIM                     52
#define          GET_BITMAPBACKSTYLE               53

// Text Commands
#define          SET_FONT                          60
#define          PRINT                             61
#define          GET_TEXTWIDTH                     62
#define          GET_TEXTHEIGHT                    63
#define          GET_TEXTLENGTH                    64
#define          GET_TEXTLINECOUNT                 65
#define          GET_FONTHEIGHT                    66
#define          GET_FONTWIDTH                     67
#define          GET_FONT                          68
#define          GET_FONTCOLORDEPTH                69

// Programming Commands
#define          PROG_HEADERS                      70
#define          PROG_GUI                          71
#define          PROG_BITMAPS                      72
#define          PROG_FONTS                        73
#define          ERASE_ALL                         74
#define          ERASE_HEADERS                     75
#define          ERASE_GUI                         76
#define          ERASE_FONTS                       77
#define          ERASE_BITMAPS                     78
#define          ERASE_AUDIO                       80
#define          PROG_AUDIO                        79

/********************************************************************************
* SegeNT Termainal Commands RXNOB and TXNOB
* TXNOB: It is the command Data Field Bytes Count
* RXNOB: It is the command Response Data Field Bytes Count
*********************************************************************************/
#define GET_PRODUCTNUMBER_TXNOB                    1
#define GET_PRODUCTNUMBER_RXNOB                    10

#define GET_FIRMWAREVERSION_TXNOB                  1
#define GET_FIRMWAREVERSION_RXNOB                  5

#define GET_SERIALNUMBER_TXNOB                     1
#define GET_SERIALNUMBER_RXNOB                     6

#define GET_USERVERSION_TXNOB                      1
#define GET_USERVERSION_RXNOB                      2

#define GET_USERIDNUMBER0_TXNOB                    1
#define GET_USERIDNUMBER0_RXNOB                    2

#define GET_USERIDNUMBER1_TXNOB                    1
#define GET_USERIDNUMBER1_RXNOB                    2

#define GET_LCDSIZE_TXNOB                          1
#define GET_LCDSIZE_RXNOB                          4

#define GET_TOUCHSCREENTYPE_TXNOB                  1
#define GET_TOUCHSCREENTYPE_RXNOB                  1

#define GET_FLASHSIZE_TXNOB                        1
#define GET_FLASHSIZE_RXNOB                        1

#define GET_USERFLASHSIZE_TXNOB                    1
#define GET_USERFLASHSIZE_RXNOB                    1

#define GET_SYSTEMSTATUS_TXNOB                     1
#define GET_SYSTEMSTATUS_RXNOB                     1

#define CAL_TOUCHSCREEN_TXNOB                      1

#define SET_BRIGHTNESS_TXNOB                       2

#define SET_BACKLIGHT_TXNOB                        2

#define SET_BEEP_TXNOB                             2

#define SET_LCD_TXNOB                              2

#define SET_USERFLASH_TXNOB                        259

#define GET_USERFLASH_TXNOB                        3
#define GET_USERFLASH_RXNOB                        256

#define ERASE_USERFLASH_TXNOB                      3

#define SET_DIGITALOUTPUT_TXNOB                    3

#define GET_DIGITALINPUT_TXNOB                     2
#define GET_DIGITALINPUT_RXNOB                     1

#define GET_ANALOGINPUT_TXNOB                      2
#define GET_ANALOGINPUT_RXNOB                      2

#define SET_PWM_TXNOB                              4

#define GET_TOUCHDATA_TXNOB                        1
#define GET_TOUCHDATA_RXNOB                        7

#define GET_PRODUCTCODE_TXNOB                      1
#define GET_PRODUCTCODE_RXNOB                      1

#define PLAY_AUDIO_TXNOB                           2

#define SET_ENTVOLUME_TXNOB                        2

#define SET_EXTVOLUME_TXNOB                        2

#define MUTE_TXNOB                                 2

#define CLEAR_SCREEN_TXNOB                         1

#define SET_BACKCOLOR_TXNOB                        3

#define SET_DRAWCOLOR_TXNOB                        3

#define SET_DRAWWIDTH_TXNOB                        2

#define SET_DRAWTYPE_TXNOB                         2

#define DRAW_LINE_TXNOB                            9

#define DRAW_RECTANGLE_TXNOB                       9

#define DRAW_FILLEDRECTANGLE_TXNOB                 9

#define DRAW_BEVEL_TXNOB                           10

#define DRAW_FILLEDBEVEL_TXNOB                     10

#define DRAW_CIRCLE_TXNOB                          9

#define DRAW_FILLEDCIRCLE_TXNOB                    9

#define DRAW_PIXEL_TXNOB                           5

#define COPY_AREA_TXNOB                            7

#define PASTE_AREA_TXNOB                           7

#define GET_PIXEL_TXNOB                            5
#define GET_PIXEL_RXNOB                            2

#define SET_ACTIVELAYER_TXNOB                      2

#define GET_ACTIVELAYER_RXNOB                      1
#define GET_ACTIVELAYER_TXNOB                      1

#define GET_COPYBUFFER_RXNOB                       2
#define GET_COPYBUFFER_TXNOB                       256

#define DRAW_BITMAP_TXNOB                          267

#define SHOW_BITMAP_TXNOB                          9

#define GET_BITMAPDIM_TXNOB                        3
#define GET_BITMAPDIM_RXNOB                        4

#define GET_BITMAPBACKSTYLE_TXNOB                  3
#define GET_BITMAPBACKSTYLE_RXNOB                  1

#define SET_FONT_TXNOB                             2

#define PRINT_TXNOB                                5

#define GET_TEXTWIDTH_TXNOB                        1
#define GET_TEXTWIDTH_RXNOB                        2

#define GET_TEXTHEIGHT_TXNOB                       1
#define GET_TEXTHEIGHT_RXNOB                       2

#define GET_TEXTLENGTH_TXNOB                       1
#define GET_TEXTLENGTH_RXNOB                       2

#define GET_TEXTLINECOUNT_TXNOB                    1
#define GET_TEXTLINECOUNT_RXNOB                    2

#define GET_FONTHEIGHT_TXNOB                       2
#define GET_FONTHEIGHT_RXNOB                       1

#define GET_FONTWIDTH_TXNOB                        2
#define GET_FONTWIDTH_RXNOB                        224

#define GET_FONT_TXNOB                             1
#define GET_FONT_RXNOB                             1

#define GET_FONTCOLORDEPTH_TXNOB                   2
#define GET_FONTCOLORDEPTH_RXNOB                   1

#define PROG_HEADERS_TXNOB                         259

#define PROG_GUI_TXNOB                             259

#define PROG_BITMAPS_TXNOB                         259

#define PROG_FONTS_TXNOB                           259

#define PROG_AUDIO_TXNOB                           259

#define ERASE_ALL_TXNOB                            3

#define ERASE_HEADERS_TXNOB                        3

#define ERASE_GUI_TXNOB                            3

#define ERASE_FONTS_TXNOB                          3

#define ERASE_BITMAPS_TXNOB                        3

#define ERASE_AUDIO_TXNOB                          3

/********************************************************************************************/
// Functions

void TerCmd_Get_ProductNumber();

void TerCmd_Get_FirmwareVersion();

void TerCmd_Get_SerialNumber();

void TerCmd_Get_UserVersion();

void TerCmd_Get_UserIDNumber0();

void TerCmd_Get_UserIDNumber1();

void TerCmd_Get_LCDSize();

void TerCmd_Get_TouchScreenType();

void TerCmd_Get_FlashSize();

void TerCmd_Get_UserFlashSize();

void TerCmd_Get_SystemStatus();

void TerCmd_Cal_TouchScreen();

void TerCmd_Set_Brightness(BYTE Value);

void TerCmd_Set_Backlight(BYTE Value);

void TerCmd_Set_Beep(BYTE Value);

void TerCmd_Set_LCD(BYTE Value);

void TerCmd_Set_UserFlash(WORD Page, BYTE* pBuffer );

void TerCmd_Get_UserFlash(WORD Page, BYTE* pBuffer );

void TerCmd_Erase_UserFlash(WORD Sector);

void TerCmd_Set_DigitalOutput(BYTE Addr, BYTE Value);

void TerCmd_Get_DigitalInput(BYTE Addr);

void TerCmd_Get_AnalogInput(BYTE Addr);

void TerCmd_Set_PWM(BYTE Addr, WORD Value);

void TerCmd_Get_TouchData();

void TerCmd_Get_ProductCode();

void TerCmd_Play_Audio(BYTE Value);

void TerCmd_Set_EntVolume(BYTE Value);

void TerCmd_Set_ExtVolume(BYTE Value);

void TerCmd_Mute(BYTE Value);

void TerCmd_Clear_Screen();

void TerCmd_Set_BackColor(WORD Value);

void TerCmd_Set_DrawColor(WORD Value);

void TerCmd_Set_DrawWidth(BYTE Value);

void TerCmd_Set_DrawType(BYTE Value);

void TerCmd_Draw_Line(WORD X1, WORD Y1, WORD X2, WORD Y2);

void TerCmd_Draw_Rectangle(WORD X1, WORD Y1, WORD X2, WORD Y2);

void TerCmd_Draw_FilledRectangle(WORD X1, WORD Y1, WORD X2, WORD Y2);

void TerCmd_Draw_Bevel(WORD X1, WORD Y1, WORD X2, WORD Y2, BYTE R);

void TerCmd_Draw_FilledBevel(WORD X1, WORD Y1, WORD X2, WORD Y2, BYTE R);

void TerCmd_Draw_Circle(WORD X0, WORD Y0, WORD R1, WORD R2);

void TerCmd_Draw_FilledCircle(WORD X0, WORD Y0, WORD R1, WORD R2);

void TerCmd_Draw_Pixel(WORD X, WORD Y);

void TerCmd_Copy_Area(WORD X, WORD Y, BYTE W, BYTE H);

void TerCmd_Paste_Area(WORD X, WORD Y, BYTE W, BYTE H);

void TerCmd_Get_Pixel(WORD X, WORD Y);

void TerCmd_Set_ActiveLayer(BYTE Value);

void TerCmd_Get_ActiveLayer();

void TerCmd_Get_CopyBuffer(BYTE Block, WORD* pBuffer);

void TerCmd_Draw_Bitmap(WORD X, WORD Y, WORD W, WORD H, WORD Block, WORD* pBuffer);

void TerCmd_Show_Bitmap(WORD ID, WORD X, WORD Y, BYTE Ori, BYTE Mir);

void TerCmd_Get_BitmapDim(WORD ID);

void TerCmd_Get_BitmapBackStyle(WORD ID);

void TerCmd_Set_Font(BYTE ID);

void TerCmd_Print(WORD CurX, WORD CurY, BYTE* pText);

void TerCmd_Get_TextWidth(BYTE* pText);

void TerCmd_Get_TextHeight(BYTE* pText);

void TerCmd_Get_TextLength(BYTE* pText);

void TerCmd_Get_TextLineCount(BYTE* pText);

void TerCmd_Get_FontHeight(BYTE ID);

void TerCmd_Get_FontWidth(BYTE ID, BYTE* pBuffer);

void TerCmd_Get_Font();

void TerCmd_Get_FontColorDepth(BYTE ID);













