/*****************************************************************************
 * UiHandler driver for SegeNT
 *****************************************************************************
 * FileName:        UiHandler.c
 * Dependencies:       
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Abdul Haidar         4/17/2014
 *****************************************************************************/
#include "MainDemo.h"
#include "UiHandler.h"
#include "RS232.h"
#include "GUICommands.h"
#include "Demo_VGA_CA32.h"



/****************************************************************************/
// Initil External Interrupt connected to SegeNT NotifyHost pin. 
void uiInit()
{
  mINT3ClearIntFlag();       // Clear INT3 interrupt flag
  mINT3SetIntPriority(4);
  mINT3SetEdgeMode(0);      // falling edge
  mINT3IntEnable(1);        // INT3 is enabled
}

/***************************************************************************/
// Get UIMsg at NotifyHost event. 
#define __INT3_ISR    __ISR(_EXTERNAL_3_VECTOR, ipl4)

void __INT3_ISR _INT3Interrupt(void)
{
  mINT3ClearIntFlag();              // Clear INT3 interrupt flag

  // Clear Global uiEvent Flag
  uiEvent = 0;

  if (CmdInProgress == 0)         // Do not send Get_uiMsg if there is a command in progress
   {
    // Clear uiService Request flag
    uiServiceRequest = 0;

    //Send GUI command Gui_Get_UIMsgAdv
    GuiCmd_Get_UIMsgAdv();

    //check Msg Status
    if (UI_Msg.Status == uiEVENT_VALID)
     { 
       // Set uiEvent flag
       uiEvent = 1;
     }
    }
  else
    {
      uiServiceRequest = 1;         // If CmdInProgress is set then set uiServiceReguest 
    }
}

/*****************************************************************************************************/
void uiService()
{
 if (uiServiceRequest == 1)
  {
    // Clear Global uiEvent Flag
    uiEvent = 0;

    // Clear uiService Request flag
    uiServiceRequest = 0;

    //Send GUI command Gui_Get_UIMsgAdv
    GuiCmd_Get_UIMsgAdv();

    //check Msg Status
    if (UI_Msg.Status == uiEVENT_VALID)
     { 
       // Set uiEvent flag
       uiEvent = 1;
     }
   }

 if (uiEvent == 1)
  {
    if (UI_Msg.ID < 64)             // check if the objID belongs to screen
     {
       switch (ActScrID)
       {
         case SCREEN_SPLASH:
         uiEvent = 0;
         return;

         case SCREEN_MAIN:
         ui_Screen_Main();
         uiEvent = 0;
         return;

         case SCREEN_DRAWPAD:
         ui_Screen_DrawPad();
         uiEvent = 0;
         return;

         case SCREEN_PHONE:
         ui_Screen_Phone();
         uiEvent = 0;
         return;

         case SCREEN_CHART:
         ui_Screen_Chart();
         uiEvent = 0;
         return;

         case SCREEN_KEYBOARD:
         ui_Screen_KeyBoard();
         uiEvent = 0;
         return;

         case SCREEN_DASHBOARD:
         ui_Screen_DashBoard();
         uiEvent = 0;
         return;

         case SCREEN_CONTROL:
         ui_Screen_Control();
         uiEvent = 0;
         return;

         case SCREEN_TIME:
         ui_Screen_Time();
         uiEvent = 0;
         return;

         case SCREEN_THERMOSTATE:
         ui_Screen_Thermostate();
         uiEvent = 0;
         return;

         case SCREEN_TOOLS:
         ui_Screen_Tools();
         uiEvent = 0;
         return;
       }
     } 
    
    if ((UI_Msg.ID >= 64)&&(UI_Msg.ID < 128))             // check if the objID belongs to Window1
     {
        switch (ActWin1ID)
        {
          case WINDOW1_COLORBOX:
          ui_Win1_ColorBox();
          uiEvent = 0;
          return;

          case WINDOW1_SHAPEBOX:
          ui_Win1_ShapeBox();
          uiEvent = 0;
          return;

          case WINDOW1_BITMAPBOX:
          ui_Win1_BitmapBox();
          uiEvent = 0;
          return;

          case  WINDOW1_FONTBOX:
          ui_Win1_FontBox();
          uiEvent = 0;
          return;

          case  WINDOW1_INFO:
          ui_Win1_Info();
          uiEvent = 0;
          return;
        }
      }

    if ((UI_Msg.ID >= 128)&&(UI_Msg.ID < 192))             // check if the objID belongs to Window2
     {
        switch (ActWin2ID)
        {
          case WINDOW2_VIDEO:
          ui_Win2_Video();
          uiEvent = 0;
          return;
        }
      }
  }
}

        

