/*****************************************************************************
 * Info Window1 driver
 *****************************************************************************
 * FileName:        Win1_Info.c
 * Dependencies:    see below
 * Processor:       PIC32
 * Compiler:       	MPLAB C32
 * Linker:          MPLAB LINK32
 * Company:         Haidar Technology, LLC.
 *
 * Software License Agreement
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *****************************************************************************/
#include "MainDemo.h"
#include "GUICommands.h"
#include "TerCommands.h"
#include "Demo_VGA_CA32.h"
#include "UiHandler.h"
#include "GUI.h"

#include "Win1_Info.h"


/********************************************************************/
void Show_Win1_Info()
{
 if (ActWin1ID == WINDOW1_INFO)
  {
    // View window
    GuiCmd_View_Form(WINDOW1_INFO, 1);
  }
 else
  {
    ActWin1ID = WINDOW1_INFO;
  
    // Load Form
    GuiCmd_Load_Form(ActWin1ID);

    // Show Form
    GuiCmd_Draw_Form(ActWin1ID);

    // Update System Info
    Update_SysInfo();

  }
}

/*******************************************************************/
void ui_Win1_Info()
{
 if (UI_Msg.Code == BUTTON_CODE)
  {
   switch (UI_Msg.ID)
   {
      case WINDOW1_INFO_BUTTON_CLOSE:
      // Hide Window
      GuiCmd_View_Form(WINDOW1_INFO, 0);
      break;
   }
  }
}

/*******************************************************************/
void Update_SysInfo()
{
 WORD CurX;
 WORD CurY;

 TerCmd_Get_ProductNumber();    
 TerCmd_Get_FirmwareVersion();
 TerCmd_Get_SerialNumber();
 TerCmd_Get_UserVersion();
 TerCmd_Get_UserIDNumber0();
 TerCmd_Get_UserIDNumber1();
 TerCmd_Get_LCDSize();
 TerCmd_Get_TouchScreenType();
 TerCmd_Get_FlashSize();
 TerCmd_Get_UserFlashSize();
 TerCmd_Get_FontHeight(1);

 CurX = 0;
 CurY = 0;

 // Update user data
 GuiCmd_TextBox_Number(WINDOW1_INFO_TEXTBOX_USERVERSION, 1, 0, UserVersion);

 GuiCmd_TextBox_Number(WINDOW1_INFO_TEXTBOX_USERID0, 1, 0, UserIDNumber0);

 GuiCmd_TextBox_Number(WINDOW1_INFO_TEXTBOX_USERID1, 1, 0, UserIDNumber1);

 // Update System data
 GuiCmd_Set_ObjProperty_Byte(PICTUREBOX_CODE, WINDOW1_INFO_PICTUREBOX_INFO, PICTUREBOX_PRO_FONT, REDRAW_NO, 1);

 GuiCmd_Set_ObjProperty_Word(PICTUREBOX_CODE, WINDOW1_INFO_PICTUREBOX_INFO, PICTUREBOX_PRO_FORECOLOR, REDRAW_NO, BRIGHTRED);

 GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) ProductNumber);

 CurY = CurY + FontHeight;
 
 GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) FirmwareVersion);

 CurY = CurY + FontHeight;
 
 GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) SerialNumber);

 CurY = CurY + 2*FontHeight;

 GuiCmd_Set_ObjProperty_Word(PICTUREBOX_CODE, WINDOW1_INFO_PICTUREBOX_INFO, PICTUREBOX_PRO_FORECOLOR, REDRAW_NO, BROWN);

 if ((LCDResX == 320) && (LCDResY == 240))
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "QVGA 320X240");
  }

 if ((LCDResX == 480) && (LCDResY == 272))
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "WQVGA 480X272");
  }

 if ((LCDResX == 640) && (LCDResY == 480))
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "VGA 640X480");
  }

 if ((LCDResX == 800) && (LCDResY == 480))
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "WVGA 800X480");
  }

 CurY = CurY + FontHeight;

 if (TouchScreenType == 0)
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "4-Wire Res TP");
  }

 if (TouchScreenType == 1)
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "5-Wire Res TP");
  }

 if (TouchScreenType == 2)
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "Cap TP");
  }

 if (TouchScreenType == 3)
  {
    GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "No TP");
  }

 CurY = CurY + FontHeight;

 GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "16MB Sys Flash");

 CurY = CurY + FontHeight;

 GuiCmd_PictureBox_Print(WINDOW1_INFO_PICTUREBOX_INFO, CurX, CurY, (char*) "64KB User Flash");

} 